// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package aiplatform aliases all exported identifiers in package
// "cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb".
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package aiplatform

import (
	src "cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
const (
	AcceleratorType_ACCELERATOR_TYPE_UNSPECIFIED                                                       = src.AcceleratorType_ACCELERATOR_TYPE_UNSPECIFIED
	AcceleratorType_NVIDIA_TESLA_A100                                                                  = src.AcceleratorType_NVIDIA_TESLA_A100
	AcceleratorType_NVIDIA_TESLA_K80                                                                   = src.AcceleratorType_NVIDIA_TESLA_K80
	AcceleratorType_NVIDIA_TESLA_P100                                                                  = src.AcceleratorType_NVIDIA_TESLA_P100
	AcceleratorType_NVIDIA_TESLA_P4                                                                    = src.AcceleratorType_NVIDIA_TESLA_P4
	AcceleratorType_NVIDIA_TESLA_T4                                                                    = src.AcceleratorType_NVIDIA_TESLA_T4
	AcceleratorType_NVIDIA_TESLA_V100                                                                  = src.AcceleratorType_NVIDIA_TESLA_V100
	AcceleratorType_TPU_V2                                                                             = src.AcceleratorType_TPU_V2
	AcceleratorType_TPU_V3                                                                             = src.AcceleratorType_TPU_V3
	Artifact_LIVE                                                                                      = src.Artifact_LIVE
	Artifact_PENDING                                                                                   = src.Artifact_PENDING
	Artifact_STATE_UNSPECIFIED                                                                         = src.Artifact_STATE_UNSPECIFIED
	Event_INPUT                                                                                        = src.Event_INPUT
	Event_OUTPUT                                                                                       = src.Event_OUTPUT
	Event_TYPE_UNSPECIFIED                                                                             = src.Event_TYPE_UNSPECIFIED
	ExamplesOverride_DATA_FORMAT_UNSPECIFIED                                                           = src.ExamplesOverride_DATA_FORMAT_UNSPECIFIED
	ExamplesOverride_EMBEDDINGS                                                                        = src.ExamplesOverride_EMBEDDINGS
	ExamplesOverride_INSTANCES                                                                         = src.ExamplesOverride_INSTANCES
	Execution_CACHED                                                                                   = src.Execution_CACHED
	Execution_CANCELLED                                                                                = src.Execution_CANCELLED
	Execution_COMPLETE                                                                                 = src.Execution_COMPLETE
	Execution_FAILED                                                                                   = src.Execution_FAILED
	Execution_NEW                                                                                      = src.Execution_NEW
	Execution_RUNNING                                                                                  = src.Execution_RUNNING
	Execution_STATE_UNSPECIFIED                                                                        = src.Execution_STATE_UNSPECIFIED
	ExplanationMetadata_InputMetadata_BAG_OF_FEATURES                                                  = src.ExplanationMetadata_InputMetadata_BAG_OF_FEATURES
	ExplanationMetadata_InputMetadata_BAG_OF_FEATURES_SPARSE                                           = src.ExplanationMetadata_InputMetadata_BAG_OF_FEATURES_SPARSE
	ExplanationMetadata_InputMetadata_COMBINED_EMBEDDING                                               = src.ExplanationMetadata_InputMetadata_COMBINED_EMBEDDING
	ExplanationMetadata_InputMetadata_CONCAT_EMBEDDING                                                 = src.ExplanationMetadata_InputMetadata_CONCAT_EMBEDDING
	ExplanationMetadata_InputMetadata_ENCODING_UNSPECIFIED                                             = src.ExplanationMetadata_InputMetadata_ENCODING_UNSPECIFIED
	ExplanationMetadata_InputMetadata_IDENTITY                                                         = src.ExplanationMetadata_InputMetadata_IDENTITY
	ExplanationMetadata_InputMetadata_INDICATOR                                                        = src.ExplanationMetadata_InputMetadata_INDICATOR
	ExplanationMetadata_InputMetadata_Visualization_BOTH                                               = src.ExplanationMetadata_InputMetadata_Visualization_BOTH
	ExplanationMetadata_InputMetadata_Visualization_COLOR_MAP_UNSPECIFIED                              = src.ExplanationMetadata_InputMetadata_Visualization_COLOR_MAP_UNSPECIFIED
	ExplanationMetadata_InputMetadata_Visualization_GRAYSCALE                                          = src.ExplanationMetadata_InputMetadata_Visualization_GRAYSCALE
	ExplanationMetadata_InputMetadata_Visualization_GREEN                                              = src.ExplanationMetadata_InputMetadata_Visualization_GREEN
	ExplanationMetadata_InputMetadata_Visualization_MASK_BLACK                                         = src.ExplanationMetadata_InputMetadata_Visualization_MASK_BLACK
	ExplanationMetadata_InputMetadata_Visualization_NEGATIVE                                           = src.ExplanationMetadata_InputMetadata_Visualization_NEGATIVE
	ExplanationMetadata_InputMetadata_Visualization_NONE                                               = src.ExplanationMetadata_InputMetadata_Visualization_NONE
	ExplanationMetadata_InputMetadata_Visualization_ORIGINAL                                           = src.ExplanationMetadata_InputMetadata_Visualization_ORIGINAL
	ExplanationMetadata_InputMetadata_Visualization_OUTLINES                                           = src.ExplanationMetadata_InputMetadata_Visualization_OUTLINES
	ExplanationMetadata_InputMetadata_Visualization_OVERLAY_TYPE_UNSPECIFIED                           = src.ExplanationMetadata_InputMetadata_Visualization_OVERLAY_TYPE_UNSPECIFIED
	ExplanationMetadata_InputMetadata_Visualization_PINK_GREEN                                         = src.ExplanationMetadata_InputMetadata_Visualization_PINK_GREEN
	ExplanationMetadata_InputMetadata_Visualization_PINK_WHITE_GREEN                                   = src.ExplanationMetadata_InputMetadata_Visualization_PINK_WHITE_GREEN
	ExplanationMetadata_InputMetadata_Visualization_PIXELS                                             = src.ExplanationMetadata_InputMetadata_Visualization_PIXELS
	ExplanationMetadata_InputMetadata_Visualization_POLARITY_UNSPECIFIED                               = src.ExplanationMetadata_InputMetadata_Visualization_POLARITY_UNSPECIFIED
	ExplanationMetadata_InputMetadata_Visualization_POSITIVE                                           = src.ExplanationMetadata_InputMetadata_Visualization_POSITIVE
	ExplanationMetadata_InputMetadata_Visualization_RED                                                = src.ExplanationMetadata_InputMetadata_Visualization_RED
	ExplanationMetadata_InputMetadata_Visualization_RED_GREEN                                          = src.ExplanationMetadata_InputMetadata_Visualization_RED_GREEN
	ExplanationMetadata_InputMetadata_Visualization_TYPE_UNSPECIFIED                                   = src.ExplanationMetadata_InputMetadata_Visualization_TYPE_UNSPECIFIED
	ExplanationMetadata_InputMetadata_Visualization_VIRIDIS                                            = src.ExplanationMetadata_InputMetadata_Visualization_VIRIDIS
	Feature_BOOL                                                                                       = src.Feature_BOOL
	Feature_BOOL_ARRAY                                                                                 = src.Feature_BOOL_ARRAY
	Feature_BYTES                                                                                      = src.Feature_BYTES
	Feature_DOUBLE                                                                                     = src.Feature_DOUBLE
	Feature_DOUBLE_ARRAY                                                                               = src.Feature_DOUBLE_ARRAY
	Feature_INT64                                                                                      = src.Feature_INT64
	Feature_INT64_ARRAY                                                                                = src.Feature_INT64_ARRAY
	Feature_MonitoringStatsAnomaly_IMPORT_FEATURE_ANALYSIS                                             = src.Feature_MonitoringStatsAnomaly_IMPORT_FEATURE_ANALYSIS
	Feature_MonitoringStatsAnomaly_OBJECTIVE_UNSPECIFIED                                               = src.Feature_MonitoringStatsAnomaly_OBJECTIVE_UNSPECIFIED
	Feature_MonitoringStatsAnomaly_SNAPSHOT_ANALYSIS                                                   = src.Feature_MonitoringStatsAnomaly_SNAPSHOT_ANALYSIS
	Feature_STRING                                                                                     = src.Feature_STRING
	Feature_STRING_ARRAY                                                                               = src.Feature_STRING_ARRAY
	Feature_VALUE_TYPE_UNSPECIFIED                                                                     = src.Feature_VALUE_TYPE_UNSPECIFIED
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_BASELINE_UNSPECIFIED                           = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_BASELINE_UNSPECIFIED
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_DEFAULT                                        = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_DEFAULT
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_DISABLED                                       = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_DISABLED
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_ENABLED                                        = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_ENABLED
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_LATEST_STATS                                   = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_LATEST_STATS
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_MOST_RECENT_SNAPSHOT_STATS                     = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_MOST_RECENT_SNAPSHOT_STATS
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_PREVIOUS_IMPORT_FEATURES_STATS                 = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_PREVIOUS_IMPORT_FEATURES_STATS
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_STATE_UNSPECIFIED                              = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_STATE_UNSPECIFIED
	Featurestore_STABLE                                                                                = src.Featurestore_STABLE
	Featurestore_STATE_UNSPECIFIED                                                                     = src.Featurestore_STATE_UNSPECIFIED
	Featurestore_UPDATING                                                                              = src.Featurestore_UPDATING
	Index_BATCH_UPDATE                                                                                 = src.Index_BATCH_UPDATE
	Index_INDEX_UPDATE_METHOD_UNSPECIFIED                                                              = src.Index_INDEX_UPDATE_METHOD_UNSPECIFIED
	Index_STREAM_UPDATE                                                                                = src.Index_STREAM_UPDATE
	JobState_JOB_STATE_CANCELLED                                                                       = src.JobState_JOB_STATE_CANCELLED
	JobState_JOB_STATE_CANCELLING                                                                      = src.JobState_JOB_STATE_CANCELLING
	JobState_JOB_STATE_EXPIRED                                                                         = src.JobState_JOB_STATE_EXPIRED
	JobState_JOB_STATE_FAILED                                                                          = src.JobState_JOB_STATE_FAILED
	JobState_JOB_STATE_PAUSED                                                                          = src.JobState_JOB_STATE_PAUSED
	JobState_JOB_STATE_PENDING                                                                         = src.JobState_JOB_STATE_PENDING
	JobState_JOB_STATE_QUEUED                                                                          = src.JobState_JOB_STATE_QUEUED
	JobState_JOB_STATE_RUNNING                                                                         = src.JobState_JOB_STATE_RUNNING
	JobState_JOB_STATE_SUCCEEDED                                                                       = src.JobState_JOB_STATE_SUCCEEDED
	JobState_JOB_STATE_UNSPECIFIED                                                                     = src.JobState_JOB_STATE_UNSPECIFIED
	JobState_JOB_STATE_UPDATING                                                                        = src.JobState_JOB_STATE_UPDATING
	MetadataSchema_ARTIFACT_TYPE                                                                       = src.MetadataSchema_ARTIFACT_TYPE
	MetadataSchema_CONTEXT_TYPE                                                                        = src.MetadataSchema_CONTEXT_TYPE
	MetadataSchema_EXECUTION_TYPE                                                                      = src.MetadataSchema_EXECUTION_TYPE
	MetadataSchema_METADATA_SCHEMA_TYPE_UNSPECIFIED                                                    = src.MetadataSchema_METADATA_SCHEMA_TYPE_UNSPECIFIED
	ModelDeploymentMonitoringBigQueryTable_EXPLAIN                                                     = src.ModelDeploymentMonitoringBigQueryTable_EXPLAIN
	ModelDeploymentMonitoringBigQueryTable_LOG_SOURCE_UNSPECIFIED                                      = src.ModelDeploymentMonitoringBigQueryTable_LOG_SOURCE_UNSPECIFIED
	ModelDeploymentMonitoringBigQueryTable_LOG_TYPE_UNSPECIFIED                                        = src.ModelDeploymentMonitoringBigQueryTable_LOG_TYPE_UNSPECIFIED
	ModelDeploymentMonitoringBigQueryTable_PREDICT                                                     = src.ModelDeploymentMonitoringBigQueryTable_PREDICT
	ModelDeploymentMonitoringBigQueryTable_SERVING                                                     = src.ModelDeploymentMonitoringBigQueryTable_SERVING
	ModelDeploymentMonitoringBigQueryTable_TRAINING                                                    = src.ModelDeploymentMonitoringBigQueryTable_TRAINING
	ModelDeploymentMonitoringJob_MONITORING_SCHEDULE_STATE_UNSPECIFIED                                 = src.ModelDeploymentMonitoringJob_MONITORING_SCHEDULE_STATE_UNSPECIFIED
	ModelDeploymentMonitoringJob_OFFLINE                                                               = src.ModelDeploymentMonitoringJob_OFFLINE
	ModelDeploymentMonitoringJob_PENDING                                                               = src.ModelDeploymentMonitoringJob_PENDING
	ModelDeploymentMonitoringJob_RUNNING                                                               = src.ModelDeploymentMonitoringJob_RUNNING
	ModelDeploymentMonitoringObjectiveType_FEATURE_ATTRIBUTION_DRIFT                                   = src.ModelDeploymentMonitoringObjectiveType_FEATURE_ATTRIBUTION_DRIFT
	ModelDeploymentMonitoringObjectiveType_FEATURE_ATTRIBUTION_SKEW                                    = src.ModelDeploymentMonitoringObjectiveType_FEATURE_ATTRIBUTION_SKEW
	ModelDeploymentMonitoringObjectiveType_MODEL_DEPLOYMENT_MONITORING_OBJECTIVE_TYPE_UNSPECIFIED      = src.ModelDeploymentMonitoringObjectiveType_MODEL_DEPLOYMENT_MONITORING_OBJECTIVE_TYPE_UNSPECIFIED
	ModelDeploymentMonitoringObjectiveType_RAW_FEATURE_DRIFT                                           = src.ModelDeploymentMonitoringObjectiveType_RAW_FEATURE_DRIFT
	ModelDeploymentMonitoringObjectiveType_RAW_FEATURE_SKEW                                            = src.ModelDeploymentMonitoringObjectiveType_RAW_FEATURE_SKEW
	ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_BIGQUERY                      = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_BIGQUERY
	ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_JSONL                         = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_JSONL
	ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PREDICTION_FORMAT_UNSPECIFIED = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PREDICTION_FORMAT_UNSPECIFIED
	ModelSourceInfo_AUTOML                                                                             = src.ModelSourceInfo_AUTOML
	ModelSourceInfo_BQML                                                                               = src.ModelSourceInfo_BQML
	ModelSourceInfo_CUSTOM                                                                             = src.ModelSourceInfo_CUSTOM
	ModelSourceInfo_MODEL_SOURCE_TYPE_UNSPECIFIED                                                      = src.ModelSourceInfo_MODEL_SOURCE_TYPE_UNSPECIFIED
	Model_AUTOMATIC_RESOURCES                                                                          = src.Model_AUTOMATIC_RESOURCES
	Model_DEDICATED_RESOURCES                                                                          = src.Model_DEDICATED_RESOURCES
	Model_DEPLOYMENT_RESOURCES_TYPE_UNSPECIFIED                                                        = src.Model_DEPLOYMENT_RESOURCES_TYPE_UNSPECIFIED
	Model_ExportFormat_ARTIFACT                                                                        = src.Model_ExportFormat_ARTIFACT
	Model_ExportFormat_EXPORTABLE_CONTENT_UNSPECIFIED                                                  = src.Model_ExportFormat_EXPORTABLE_CONTENT_UNSPECIFIED
	Model_ExportFormat_IMAGE                                                                           = src.Model_ExportFormat_IMAGE
	Model_SHARED_RESOURCES                                                                             = src.Model_SHARED_RESOURCES
	NearestNeighborSearchOperationMetadata_RecordError_EMBEDDING_SIZE_MISMATCH                         = src.NearestNeighborSearchOperationMetadata_RecordError_EMBEDDING_SIZE_MISMATCH
	NearestNeighborSearchOperationMetadata_RecordError_EMPTY_LINE                                      = src.NearestNeighborSearchOperationMetadata_RecordError_EMPTY_LINE
	NearestNeighborSearchOperationMetadata_RecordError_ERROR_TYPE_UNSPECIFIED                          = src.NearestNeighborSearchOperationMetadata_RecordError_ERROR_TYPE_UNSPECIFIED
	NearestNeighborSearchOperationMetadata_RecordError_INVALID_AVRO_SYNTAX                             = src.NearestNeighborSearchOperationMetadata_RecordError_INVALID_AVRO_SYNTAX
	NearestNeighborSearchOperationMetadata_RecordError_INVALID_CSV_SYNTAX                              = src.NearestNeighborSearchOperationMetadata_RecordError_INVALID_CSV_SYNTAX
	NearestNeighborSearchOperationMetadata_RecordError_INVALID_EMBEDDING_ID                            = src.NearestNeighborSearchOperationMetadata_RecordError_INVALID_EMBEDDING_ID
	NearestNeighborSearchOperationMetadata_RecordError_INVALID_JSON_SYNTAX                             = src.NearestNeighborSearchOperationMetadata_RecordError_INVALID_JSON_SYNTAX
	NearestNeighborSearchOperationMetadata_RecordError_NAMESPACE_MISSING                               = src.NearestNeighborSearchOperationMetadata_RecordError_NAMESPACE_MISSING
	PipelineFailurePolicy_PIPELINE_FAILURE_POLICY_FAIL_FAST                                            = src.PipelineFailurePolicy_PIPELINE_FAILURE_POLICY_FAIL_FAST
	PipelineFailurePolicy_PIPELINE_FAILURE_POLICY_FAIL_SLOW                                            = src.PipelineFailurePolicy_PIPELINE_FAILURE_POLICY_FAIL_SLOW
	PipelineFailurePolicy_PIPELINE_FAILURE_POLICY_UNSPECIFIED                                          = src.PipelineFailurePolicy_PIPELINE_FAILURE_POLICY_UNSPECIFIED
	PipelineState_PIPELINE_STATE_CANCELLED                                                             = src.PipelineState_PIPELINE_STATE_CANCELLED
	PipelineState_PIPELINE_STATE_CANCELLING                                                            = src.PipelineState_PIPELINE_STATE_CANCELLING
	PipelineState_PIPELINE_STATE_FAILED                                                                = src.PipelineState_PIPELINE_STATE_FAILED
	PipelineState_PIPELINE_STATE_PAUSED                                                                = src.PipelineState_PIPELINE_STATE_PAUSED
	PipelineState_PIPELINE_STATE_PENDING                                                               = src.PipelineState_PIPELINE_STATE_PENDING
	PipelineState_PIPELINE_STATE_QUEUED                                                                = src.PipelineState_PIPELINE_STATE_QUEUED
	PipelineState_PIPELINE_STATE_RUNNING                                                               = src.PipelineState_PIPELINE_STATE_RUNNING
	PipelineState_PIPELINE_STATE_SUCCEEDED                                                             = src.PipelineState_PIPELINE_STATE_SUCCEEDED
	PipelineState_PIPELINE_STATE_UNSPECIFIED                                                           = src.PipelineState_PIPELINE_STATE_UNSPECIFIED
	PipelineTaskDetail_CANCELLED                                                                       = src.PipelineTaskDetail_CANCELLED
	PipelineTaskDetail_CANCELLING                                                                      = src.PipelineTaskDetail_CANCELLING
	PipelineTaskDetail_CANCEL_PENDING                                                                  = src.PipelineTaskDetail_CANCEL_PENDING
	PipelineTaskDetail_FAILED                                                                          = src.PipelineTaskDetail_FAILED
	PipelineTaskDetail_NOT_TRIGGERED                                                                   = src.PipelineTaskDetail_NOT_TRIGGERED
	PipelineTaskDetail_PENDING                                                                         = src.PipelineTaskDetail_PENDING
	PipelineTaskDetail_RUNNING                                                                         = src.PipelineTaskDetail_RUNNING
	PipelineTaskDetail_SKIPPED                                                                         = src.PipelineTaskDetail_SKIPPED
	PipelineTaskDetail_STATE_UNSPECIFIED                                                               = src.PipelineTaskDetail_STATE_UNSPECIFIED
	PipelineTaskDetail_SUCCEEDED                                                                       = src.PipelineTaskDetail_SUCCEEDED
	Presets_FAST                                                                                       = src.Presets_FAST
	Presets_IMAGE                                                                                      = src.Presets_IMAGE
	Presets_MODALITY_UNSPECIFIED                                                                       = src.Presets_MODALITY_UNSPECIFIED
	Presets_PRECISE                                                                                    = src.Presets_PRECISE
	Presets_TABULAR                                                                                    = src.Presets_TABULAR
	Presets_TEXT                                                                                       = src.Presets_TEXT
	SampleConfig_SAMPLE_STRATEGY_UNSPECIFIED                                                           = src.SampleConfig_SAMPLE_STRATEGY_UNSPECIFIED
	SampleConfig_UNCERTAINTY                                                                           = src.SampleConfig_UNCERTAINTY
	StudySpec_ALGORITHM_UNSPECIFIED                                                                    = src.StudySpec_ALGORITHM_UNSPECIFIED
	StudySpec_BEST_MEASUREMENT                                                                         = src.StudySpec_BEST_MEASUREMENT
	StudySpec_GRID_SEARCH                                                                              = src.StudySpec_GRID_SEARCH
	StudySpec_HIGH                                                                                     = src.StudySpec_HIGH
	StudySpec_LAST_MEASUREMENT                                                                         = src.StudySpec_LAST_MEASUREMENT
	StudySpec_LOW                                                                                      = src.StudySpec_LOW
	StudySpec_MEASUREMENT_SELECTION_TYPE_UNSPECIFIED                                                   = src.StudySpec_MEASUREMENT_SELECTION_TYPE_UNSPECIFIED
	StudySpec_MetricSpec_GOAL_TYPE_UNSPECIFIED                                                         = src.StudySpec_MetricSpec_GOAL_TYPE_UNSPECIFIED
	StudySpec_MetricSpec_MAXIMIZE                                                                      = src.StudySpec_MetricSpec_MAXIMIZE
	StudySpec_MetricSpec_MINIMIZE                                                                      = src.StudySpec_MetricSpec_MINIMIZE
	StudySpec_OBSERVATION_NOISE_UNSPECIFIED                                                            = src.StudySpec_OBSERVATION_NOISE_UNSPECIFIED
	StudySpec_ParameterSpec_SCALE_TYPE_UNSPECIFIED                                                     = src.StudySpec_ParameterSpec_SCALE_TYPE_UNSPECIFIED
	StudySpec_ParameterSpec_UNIT_LINEAR_SCALE                                                          = src.StudySpec_ParameterSpec_UNIT_LINEAR_SCALE
	StudySpec_ParameterSpec_UNIT_LOG_SCALE                                                             = src.StudySpec_ParameterSpec_UNIT_LOG_SCALE
	StudySpec_ParameterSpec_UNIT_REVERSE_LOG_SCALE                                                     = src.StudySpec_ParameterSpec_UNIT_REVERSE_LOG_SCALE
	StudySpec_RANDOM_SEARCH                                                                            = src.StudySpec_RANDOM_SEARCH
	Study_ACTIVE                                                                                       = src.Study_ACTIVE
	Study_COMPLETED                                                                                    = src.Study_COMPLETED
	Study_INACTIVE                                                                                     = src.Study_INACTIVE
	Study_STATE_UNSPECIFIED                                                                            = src.Study_STATE_UNSPECIFIED
	TensorboardTimeSeries_BLOB_SEQUENCE                                                                = src.TensorboardTimeSeries_BLOB_SEQUENCE
	TensorboardTimeSeries_SCALAR                                                                       = src.TensorboardTimeSeries_SCALAR
	TensorboardTimeSeries_TENSOR                                                                       = src.TensorboardTimeSeries_TENSOR
	TensorboardTimeSeries_VALUE_TYPE_UNSPECIFIED                                                       = src.TensorboardTimeSeries_VALUE_TYPE_UNSPECIFIED
	Trial_ACTIVE                                                                                       = src.Trial_ACTIVE
	Trial_INFEASIBLE                                                                                   = src.Trial_INFEASIBLE
	Trial_REQUESTED                                                                                    = src.Trial_REQUESTED
	Trial_STATE_UNSPECIFIED                                                                            = src.Trial_STATE_UNSPECIFIED
	Trial_STOPPING                                                                                     = src.Trial_STOPPING
	Trial_SUCCEEDED                                                                                    = src.Trial_SUCCEEDED
)

// Deprecated: Please use vars in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
var (
	AcceleratorType_name                                                                        = src.AcceleratorType_name
	AcceleratorType_value                                                                       = src.AcceleratorType_value
	Artifact_State_name                                                                         = src.Artifact_State_name
	Artifact_State_value                                                                        = src.Artifact_State_value
	Event_Type_name                                                                             = src.Event_Type_name
	Event_Type_value                                                                            = src.Event_Type_value
	ExamplesOverride_DataFormat_name                                                            = src.ExamplesOverride_DataFormat_name
	ExamplesOverride_DataFormat_value                                                           = src.ExamplesOverride_DataFormat_value
	Execution_State_name                                                                        = src.Execution_State_name
	Execution_State_value                                                                       = src.Execution_State_value
	ExplanationMetadata_InputMetadata_Encoding_name                                             = src.ExplanationMetadata_InputMetadata_Encoding_name
	ExplanationMetadata_InputMetadata_Encoding_value                                            = src.ExplanationMetadata_InputMetadata_Encoding_value
	ExplanationMetadata_InputMetadata_Visualization_ColorMap_name                               = src.ExplanationMetadata_InputMetadata_Visualization_ColorMap_name
	ExplanationMetadata_InputMetadata_Visualization_ColorMap_value                              = src.ExplanationMetadata_InputMetadata_Visualization_ColorMap_value
	ExplanationMetadata_InputMetadata_Visualization_OverlayType_name                            = src.ExplanationMetadata_InputMetadata_Visualization_OverlayType_name
	ExplanationMetadata_InputMetadata_Visualization_OverlayType_value                           = src.ExplanationMetadata_InputMetadata_Visualization_OverlayType_value
	ExplanationMetadata_InputMetadata_Visualization_Polarity_name                               = src.ExplanationMetadata_InputMetadata_Visualization_Polarity_name
	ExplanationMetadata_InputMetadata_Visualization_Polarity_value                              = src.ExplanationMetadata_InputMetadata_Visualization_Polarity_value
	ExplanationMetadata_InputMetadata_Visualization_Type_name                                   = src.ExplanationMetadata_InputMetadata_Visualization_Type_name
	ExplanationMetadata_InputMetadata_Visualization_Type_value                                  = src.ExplanationMetadata_InputMetadata_Visualization_Type_value
	Feature_MonitoringStatsAnomaly_Objective_name                                               = src.Feature_MonitoringStatsAnomaly_Objective_name
	Feature_MonitoringStatsAnomaly_Objective_value                                              = src.Feature_MonitoringStatsAnomaly_Objective_value
	Feature_ValueType_name                                                                      = src.Feature_ValueType_name
	Feature_ValueType_value                                                                     = src.Feature_ValueType_value
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline_name                           = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline_name
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline_value                          = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline_value
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State_name                              = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State_name
	FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State_value                             = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State_value
	Featurestore_State_name                                                                     = src.Featurestore_State_name
	Featurestore_State_value                                                                    = src.Featurestore_State_value
	File_google_cloud_aiplatform_v1beta1_accelerator_type_proto                                 = src.File_google_cloud_aiplatform_v1beta1_accelerator_type_proto
	File_google_cloud_aiplatform_v1beta1_annotation_proto                                       = src.File_google_cloud_aiplatform_v1beta1_annotation_proto
	File_google_cloud_aiplatform_v1beta1_annotation_spec_proto                                  = src.File_google_cloud_aiplatform_v1beta1_annotation_spec_proto
	File_google_cloud_aiplatform_v1beta1_artifact_proto                                         = src.File_google_cloud_aiplatform_v1beta1_artifact_proto
	File_google_cloud_aiplatform_v1beta1_batch_prediction_job_proto                             = src.File_google_cloud_aiplatform_v1beta1_batch_prediction_job_proto
	File_google_cloud_aiplatform_v1beta1_completion_stats_proto                                 = src.File_google_cloud_aiplatform_v1beta1_completion_stats_proto
	File_google_cloud_aiplatform_v1beta1_context_proto                                          = src.File_google_cloud_aiplatform_v1beta1_context_proto
	File_google_cloud_aiplatform_v1beta1_custom_job_proto                                       = src.File_google_cloud_aiplatform_v1beta1_custom_job_proto
	File_google_cloud_aiplatform_v1beta1_data_item_proto                                        = src.File_google_cloud_aiplatform_v1beta1_data_item_proto
	File_google_cloud_aiplatform_v1beta1_data_labeling_job_proto                                = src.File_google_cloud_aiplatform_v1beta1_data_labeling_job_proto
	File_google_cloud_aiplatform_v1beta1_dataset_proto                                          = src.File_google_cloud_aiplatform_v1beta1_dataset_proto
	File_google_cloud_aiplatform_v1beta1_dataset_service_proto                                  = src.File_google_cloud_aiplatform_v1beta1_dataset_service_proto
	File_google_cloud_aiplatform_v1beta1_deployed_index_ref_proto                               = src.File_google_cloud_aiplatform_v1beta1_deployed_index_ref_proto
	File_google_cloud_aiplatform_v1beta1_deployed_model_ref_proto                               = src.File_google_cloud_aiplatform_v1beta1_deployed_model_ref_proto
	File_google_cloud_aiplatform_v1beta1_deployment_resource_pool_proto                         = src.File_google_cloud_aiplatform_v1beta1_deployment_resource_pool_proto
	File_google_cloud_aiplatform_v1beta1_deployment_resource_pool_service_proto                 = src.File_google_cloud_aiplatform_v1beta1_deployment_resource_pool_service_proto
	File_google_cloud_aiplatform_v1beta1_encryption_spec_proto                                  = src.File_google_cloud_aiplatform_v1beta1_encryption_spec_proto
	File_google_cloud_aiplatform_v1beta1_endpoint_proto                                         = src.File_google_cloud_aiplatform_v1beta1_endpoint_proto
	File_google_cloud_aiplatform_v1beta1_endpoint_service_proto                                 = src.File_google_cloud_aiplatform_v1beta1_endpoint_service_proto
	File_google_cloud_aiplatform_v1beta1_entity_type_proto                                      = src.File_google_cloud_aiplatform_v1beta1_entity_type_proto
	File_google_cloud_aiplatform_v1beta1_env_var_proto                                          = src.File_google_cloud_aiplatform_v1beta1_env_var_proto
	File_google_cloud_aiplatform_v1beta1_event_proto                                            = src.File_google_cloud_aiplatform_v1beta1_event_proto
	File_google_cloud_aiplatform_v1beta1_execution_proto                                        = src.File_google_cloud_aiplatform_v1beta1_execution_proto
	File_google_cloud_aiplatform_v1beta1_explanation_metadata_proto                             = src.File_google_cloud_aiplatform_v1beta1_explanation_metadata_proto
	File_google_cloud_aiplatform_v1beta1_explanation_proto                                      = src.File_google_cloud_aiplatform_v1beta1_explanation_proto
	File_google_cloud_aiplatform_v1beta1_feature_monitoring_stats_proto                         = src.File_google_cloud_aiplatform_v1beta1_feature_monitoring_stats_proto
	File_google_cloud_aiplatform_v1beta1_feature_proto                                          = src.File_google_cloud_aiplatform_v1beta1_feature_proto
	File_google_cloud_aiplatform_v1beta1_feature_selector_proto                                 = src.File_google_cloud_aiplatform_v1beta1_feature_selector_proto
	File_google_cloud_aiplatform_v1beta1_featurestore_monitoring_proto                          = src.File_google_cloud_aiplatform_v1beta1_featurestore_monitoring_proto
	File_google_cloud_aiplatform_v1beta1_featurestore_online_service_proto                      = src.File_google_cloud_aiplatform_v1beta1_featurestore_online_service_proto
	File_google_cloud_aiplatform_v1beta1_featurestore_proto                                     = src.File_google_cloud_aiplatform_v1beta1_featurestore_proto
	File_google_cloud_aiplatform_v1beta1_featurestore_service_proto                             = src.File_google_cloud_aiplatform_v1beta1_featurestore_service_proto
	File_google_cloud_aiplatform_v1beta1_hyperparameter_tuning_job_proto                        = src.File_google_cloud_aiplatform_v1beta1_hyperparameter_tuning_job_proto
	File_google_cloud_aiplatform_v1beta1_index_endpoint_proto                                   = src.File_google_cloud_aiplatform_v1beta1_index_endpoint_proto
	File_google_cloud_aiplatform_v1beta1_index_endpoint_service_proto                           = src.File_google_cloud_aiplatform_v1beta1_index_endpoint_service_proto
	File_google_cloud_aiplatform_v1beta1_index_proto                                            = src.File_google_cloud_aiplatform_v1beta1_index_proto
	File_google_cloud_aiplatform_v1beta1_index_service_proto                                    = src.File_google_cloud_aiplatform_v1beta1_index_service_proto
	File_google_cloud_aiplatform_v1beta1_io_proto                                               = src.File_google_cloud_aiplatform_v1beta1_io_proto
	File_google_cloud_aiplatform_v1beta1_job_service_proto                                      = src.File_google_cloud_aiplatform_v1beta1_job_service_proto
	File_google_cloud_aiplatform_v1beta1_job_state_proto                                        = src.File_google_cloud_aiplatform_v1beta1_job_state_proto
	File_google_cloud_aiplatform_v1beta1_lineage_subgraph_proto                                 = src.File_google_cloud_aiplatform_v1beta1_lineage_subgraph_proto
	File_google_cloud_aiplatform_v1beta1_machine_resources_proto                                = src.File_google_cloud_aiplatform_v1beta1_machine_resources_proto
	File_google_cloud_aiplatform_v1beta1_manual_batch_tuning_parameters_proto                   = src.File_google_cloud_aiplatform_v1beta1_manual_batch_tuning_parameters_proto
	File_google_cloud_aiplatform_v1beta1_metadata_schema_proto                                  = src.File_google_cloud_aiplatform_v1beta1_metadata_schema_proto
	File_google_cloud_aiplatform_v1beta1_metadata_service_proto                                 = src.File_google_cloud_aiplatform_v1beta1_metadata_service_proto
	File_google_cloud_aiplatform_v1beta1_metadata_store_proto                                   = src.File_google_cloud_aiplatform_v1beta1_metadata_store_proto
	File_google_cloud_aiplatform_v1beta1_migratable_resource_proto                              = src.File_google_cloud_aiplatform_v1beta1_migratable_resource_proto
	File_google_cloud_aiplatform_v1beta1_migration_service_proto                                = src.File_google_cloud_aiplatform_v1beta1_migration_service_proto
	File_google_cloud_aiplatform_v1beta1_model_deployment_monitoring_job_proto                  = src.File_google_cloud_aiplatform_v1beta1_model_deployment_monitoring_job_proto
	File_google_cloud_aiplatform_v1beta1_model_evaluation_proto                                 = src.File_google_cloud_aiplatform_v1beta1_model_evaluation_proto
	File_google_cloud_aiplatform_v1beta1_model_evaluation_slice_proto                           = src.File_google_cloud_aiplatform_v1beta1_model_evaluation_slice_proto
	File_google_cloud_aiplatform_v1beta1_model_monitoring_proto                                 = src.File_google_cloud_aiplatform_v1beta1_model_monitoring_proto
	File_google_cloud_aiplatform_v1beta1_model_proto                                            = src.File_google_cloud_aiplatform_v1beta1_model_proto
	File_google_cloud_aiplatform_v1beta1_model_service_proto                                    = src.File_google_cloud_aiplatform_v1beta1_model_service_proto
	File_google_cloud_aiplatform_v1beta1_operation_proto                                        = src.File_google_cloud_aiplatform_v1beta1_operation_proto
	File_google_cloud_aiplatform_v1beta1_pipeline_failure_policy_proto                          = src.File_google_cloud_aiplatform_v1beta1_pipeline_failure_policy_proto
	File_google_cloud_aiplatform_v1beta1_pipeline_job_proto                                     = src.File_google_cloud_aiplatform_v1beta1_pipeline_job_proto
	File_google_cloud_aiplatform_v1beta1_pipeline_service_proto                                 = src.File_google_cloud_aiplatform_v1beta1_pipeline_service_proto
	File_google_cloud_aiplatform_v1beta1_pipeline_state_proto                                   = src.File_google_cloud_aiplatform_v1beta1_pipeline_state_proto
	File_google_cloud_aiplatform_v1beta1_prediction_service_proto                               = src.File_google_cloud_aiplatform_v1beta1_prediction_service_proto
	File_google_cloud_aiplatform_v1beta1_saved_query_proto                                      = src.File_google_cloud_aiplatform_v1beta1_saved_query_proto
	File_google_cloud_aiplatform_v1beta1_specialist_pool_proto                                  = src.File_google_cloud_aiplatform_v1beta1_specialist_pool_proto
	File_google_cloud_aiplatform_v1beta1_specialist_pool_service_proto                          = src.File_google_cloud_aiplatform_v1beta1_specialist_pool_service_proto
	File_google_cloud_aiplatform_v1beta1_study_proto                                            = src.File_google_cloud_aiplatform_v1beta1_study_proto
	File_google_cloud_aiplatform_v1beta1_tensorboard_data_proto                                 = src.File_google_cloud_aiplatform_v1beta1_tensorboard_data_proto
	File_google_cloud_aiplatform_v1beta1_tensorboard_experiment_proto                           = src.File_google_cloud_aiplatform_v1beta1_tensorboard_experiment_proto
	File_google_cloud_aiplatform_v1beta1_tensorboard_proto                                      = src.File_google_cloud_aiplatform_v1beta1_tensorboard_proto
	File_google_cloud_aiplatform_v1beta1_tensorboard_run_proto                                  = src.File_google_cloud_aiplatform_v1beta1_tensorboard_run_proto
	File_google_cloud_aiplatform_v1beta1_tensorboard_service_proto                              = src.File_google_cloud_aiplatform_v1beta1_tensorboard_service_proto
	File_google_cloud_aiplatform_v1beta1_tensorboard_time_series_proto                          = src.File_google_cloud_aiplatform_v1beta1_tensorboard_time_series_proto
	File_google_cloud_aiplatform_v1beta1_training_pipeline_proto                                = src.File_google_cloud_aiplatform_v1beta1_training_pipeline_proto
	File_google_cloud_aiplatform_v1beta1_types_proto                                            = src.File_google_cloud_aiplatform_v1beta1_types_proto
	File_google_cloud_aiplatform_v1beta1_unmanaged_container_model_proto                        = src.File_google_cloud_aiplatform_v1beta1_unmanaged_container_model_proto
	File_google_cloud_aiplatform_v1beta1_user_action_reference_proto                            = src.File_google_cloud_aiplatform_v1beta1_user_action_reference_proto
	File_google_cloud_aiplatform_v1beta1_value_proto                                            = src.File_google_cloud_aiplatform_v1beta1_value_proto
	File_google_cloud_aiplatform_v1beta1_vizier_service_proto                                   = src.File_google_cloud_aiplatform_v1beta1_vizier_service_proto
	Index_IndexUpdateMethod_name                                                                = src.Index_IndexUpdateMethod_name
	Index_IndexUpdateMethod_value                                                               = src.Index_IndexUpdateMethod_value
	JobState_name                                                                               = src.JobState_name
	JobState_value                                                                              = src.JobState_value
	MetadataSchema_MetadataSchemaType_name                                                      = src.MetadataSchema_MetadataSchemaType_name
	MetadataSchema_MetadataSchemaType_value                                                     = src.MetadataSchema_MetadataSchemaType_value
	ModelDeploymentMonitoringBigQueryTable_LogSource_name                                       = src.ModelDeploymentMonitoringBigQueryTable_LogSource_name
	ModelDeploymentMonitoringBigQueryTable_LogSource_value                                      = src.ModelDeploymentMonitoringBigQueryTable_LogSource_value
	ModelDeploymentMonitoringBigQueryTable_LogType_name                                         = src.ModelDeploymentMonitoringBigQueryTable_LogType_name
	ModelDeploymentMonitoringBigQueryTable_LogType_value                                        = src.ModelDeploymentMonitoringBigQueryTable_LogType_value
	ModelDeploymentMonitoringJob_MonitoringScheduleState_name                                   = src.ModelDeploymentMonitoringJob_MonitoringScheduleState_name
	ModelDeploymentMonitoringJob_MonitoringScheduleState_value                                  = src.ModelDeploymentMonitoringJob_MonitoringScheduleState_value
	ModelDeploymentMonitoringObjectiveType_name                                                 = src.ModelDeploymentMonitoringObjectiveType_name
	ModelDeploymentMonitoringObjectiveType_value                                                = src.ModelDeploymentMonitoringObjectiveType_value
	ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PredictionFormat_name  = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PredictionFormat_name
	ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PredictionFormat_value = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PredictionFormat_value
	ModelSourceInfo_ModelSourceType_name                                                        = src.ModelSourceInfo_ModelSourceType_name
	ModelSourceInfo_ModelSourceType_value                                                       = src.ModelSourceInfo_ModelSourceType_value
	Model_DeploymentResourcesType_name                                                          = src.Model_DeploymentResourcesType_name
	Model_DeploymentResourcesType_value                                                         = src.Model_DeploymentResourcesType_value
	Model_ExportFormat_ExportableContent_name                                                   = src.Model_ExportFormat_ExportableContent_name
	Model_ExportFormat_ExportableContent_value                                                  = src.Model_ExportFormat_ExportableContent_value
	NearestNeighborSearchOperationMetadata_RecordError_RecordErrorType_name                     = src.NearestNeighborSearchOperationMetadata_RecordError_RecordErrorType_name
	NearestNeighborSearchOperationMetadata_RecordError_RecordErrorType_value                    = src.NearestNeighborSearchOperationMetadata_RecordError_RecordErrorType_value
	PipelineFailurePolicy_name                                                                  = src.PipelineFailurePolicy_name
	PipelineFailurePolicy_value                                                                 = src.PipelineFailurePolicy_value
	PipelineState_name                                                                          = src.PipelineState_name
	PipelineState_value                                                                         = src.PipelineState_value
	PipelineTaskDetail_State_name                                                               = src.PipelineTaskDetail_State_name
	PipelineTaskDetail_State_value                                                              = src.PipelineTaskDetail_State_value
	Presets_Modality_name                                                                       = src.Presets_Modality_name
	Presets_Modality_value                                                                      = src.Presets_Modality_value
	Presets_Query_name                                                                          = src.Presets_Query_name
	Presets_Query_value                                                                         = src.Presets_Query_value
	SampleConfig_SampleStrategy_name                                                            = src.SampleConfig_SampleStrategy_name
	SampleConfig_SampleStrategy_value                                                           = src.SampleConfig_SampleStrategy_value
	StudySpec_Algorithm_name                                                                    = src.StudySpec_Algorithm_name
	StudySpec_Algorithm_value                                                                   = src.StudySpec_Algorithm_value
	StudySpec_MeasurementSelectionType_name                                                     = src.StudySpec_MeasurementSelectionType_name
	StudySpec_MeasurementSelectionType_value                                                    = src.StudySpec_MeasurementSelectionType_value
	StudySpec_MetricSpec_GoalType_name                                                          = src.StudySpec_MetricSpec_GoalType_name
	StudySpec_MetricSpec_GoalType_value                                                         = src.StudySpec_MetricSpec_GoalType_value
	StudySpec_ObservationNoise_name                                                             = src.StudySpec_ObservationNoise_name
	StudySpec_ObservationNoise_value                                                            = src.StudySpec_ObservationNoise_value
	StudySpec_ParameterSpec_ScaleType_name                                                      = src.StudySpec_ParameterSpec_ScaleType_name
	StudySpec_ParameterSpec_ScaleType_value                                                     = src.StudySpec_ParameterSpec_ScaleType_value
	Study_State_name                                                                            = src.Study_State_name
	Study_State_value                                                                           = src.Study_State_value
	TensorboardTimeSeries_ValueType_name                                                        = src.TensorboardTimeSeries_ValueType_name
	TensorboardTimeSeries_ValueType_value                                                       = src.TensorboardTimeSeries_ValueType_value
	Trial_State_name                                                                            = src.Trial_State_name
	Trial_State_value                                                                           = src.Trial_State_value
)

// Represents a hardware accelerator type.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AcceleratorType = src.AcceleratorType

// Parameters that configure the active learning pipeline. Active learning
// will label the data incrementally by several iterations. For every
// iteration, it will select a batch of data based on the sampling strategy.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ActiveLearningConfig = src.ActiveLearningConfig
type ActiveLearningConfig_MaxDataItemCount = src.ActiveLearningConfig_MaxDataItemCount
type ActiveLearningConfig_MaxDataItemPercentage = src.ActiveLearningConfig_MaxDataItemPercentage

// Request message for
// [MetadataService.AddContextArtifactsAndExecutions][google.cloud.aiplatform.v1beta1.MetadataService.AddContextArtifactsAndExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddContextArtifactsAndExecutionsRequest = src.AddContextArtifactsAndExecutionsRequest

// Response message for
// [MetadataService.AddContextArtifactsAndExecutions][google.cloud.aiplatform.v1beta1.MetadataService.AddContextArtifactsAndExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddContextArtifactsAndExecutionsResponse = src.AddContextArtifactsAndExecutionsResponse

// Request message for
// [MetadataService.AddContextChildren][google.cloud.aiplatform.v1beta1.MetadataService.AddContextChildren].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddContextChildrenRequest = src.AddContextChildrenRequest

// Response message for
// [MetadataService.AddContextChildren][google.cloud.aiplatform.v1beta1.MetadataService.AddContextChildren].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddContextChildrenResponse = src.AddContextChildrenResponse

// Request message for
// [MetadataService.AddExecutionEvents][google.cloud.aiplatform.v1beta1.MetadataService.AddExecutionEvents].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddExecutionEventsRequest = src.AddExecutionEventsRequest

// Response message for
// [MetadataService.AddExecutionEvents][google.cloud.aiplatform.v1beta1.MetadataService.AddExecutionEvents].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddExecutionEventsResponse = src.AddExecutionEventsResponse

// Request message for
// [VizierService.AddTrialMeasurement][google.cloud.aiplatform.v1beta1.VizierService.AddTrialMeasurement].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AddTrialMeasurementRequest = src.AddTrialMeasurementRequest

// Used to assign specific AnnotationSpec to a particular area of a DataItem
// or the whole part of the DataItem.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Annotation = src.Annotation

// Identifies a concept with which DataItems may be annotated with.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AnnotationSpec = src.AnnotationSpec

// Instance of a general artifact.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Artifact = src.Artifact

// Describes the state of the Artifact.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Artifact_State = src.Artifact_State

// Attribution that explains a particular prediction output.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Attribution = src.Attribution

// A description of resources that to large degree are decided by Vertex AI,
// and require only a modest additional configuration. Each Model supporting
// these resources documents its specific guidelines.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AutomaticResources = src.AutomaticResources

// The metric specification that defines the target resource utilization (CPU
// utilization, accelerator's duty cycle, and so on) for calculating the
// desired replica count.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AutoscalingMetricSpec = src.AutoscalingMetricSpec

// The storage details for Avro input content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type AvroSource = src.AvroSource

// Details of operations that perform batch create Features.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateFeaturesOperationMetadata = src.BatchCreateFeaturesOperationMetadata

// Request message for
// [FeaturestoreService.BatchCreateFeatures][google.cloud.aiplatform.v1beta1.FeaturestoreService.BatchCreateFeatures].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateFeaturesRequest = src.BatchCreateFeaturesRequest

// Response message for
// [FeaturestoreService.BatchCreateFeatures][google.cloud.aiplatform.v1beta1.FeaturestoreService.BatchCreateFeatures].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateFeaturesResponse = src.BatchCreateFeaturesResponse

// Request message for
// [TensorboardService.BatchCreateTensorboardRuns][google.cloud.aiplatform.v1beta1.TensorboardService.BatchCreateTensorboardRuns].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateTensorboardRunsRequest = src.BatchCreateTensorboardRunsRequest

// Response message for
// [TensorboardService.BatchCreateTensorboardRuns][google.cloud.aiplatform.v1beta1.TensorboardService.BatchCreateTensorboardRuns].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateTensorboardRunsResponse = src.BatchCreateTensorboardRunsResponse

// Request message for
// [TensorboardService.BatchCreateTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.BatchCreateTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateTensorboardTimeSeriesRequest = src.BatchCreateTensorboardTimeSeriesRequest

// Response message for
// [TensorboardService.BatchCreateTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.BatchCreateTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchCreateTensorboardTimeSeriesResponse = src.BatchCreateTensorboardTimeSeriesResponse

// A description of resources that are used for performing batch operations,
// are dedicated to a Model, and need manual configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchDedicatedResources = src.BatchDedicatedResources

// Request message for
// [ModelService.BatchImportModelEvaluationSlices][google.cloud.aiplatform.v1beta1.ModelService.BatchImportModelEvaluationSlices]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchImportModelEvaluationSlicesRequest = src.BatchImportModelEvaluationSlicesRequest

// Response message for
// [ModelService.BatchImportModelEvaluationSlices][google.cloud.aiplatform.v1beta1.ModelService.BatchImportModelEvaluationSlices]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchImportModelEvaluationSlicesResponse = src.BatchImportModelEvaluationSlicesResponse

// Runtime operation information for
// [MigrationService.BatchMigrateResources][google.cloud.aiplatform.v1beta1.MigrationService.BatchMigrateResources].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchMigrateResourcesOperationMetadata = src.BatchMigrateResourcesOperationMetadata

// Represents a partial result in batch migration operation for one
// [MigrateResourceRequest][google.cloud.aiplatform.v1beta1.MigrateResourceRequest].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchMigrateResourcesOperationMetadata_PartialResult = src.BatchMigrateResourcesOperationMetadata_PartialResult
type BatchMigrateResourcesOperationMetadata_PartialResult_Dataset = src.BatchMigrateResourcesOperationMetadata_PartialResult_Dataset
type BatchMigrateResourcesOperationMetadata_PartialResult_Error = src.BatchMigrateResourcesOperationMetadata_PartialResult_Error
type BatchMigrateResourcesOperationMetadata_PartialResult_Model = src.BatchMigrateResourcesOperationMetadata_PartialResult_Model

// Request message for
// [MigrationService.BatchMigrateResources][google.cloud.aiplatform.v1beta1.MigrationService.BatchMigrateResources].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchMigrateResourcesRequest = src.BatchMigrateResourcesRequest

// Response message for
// [MigrationService.BatchMigrateResources][google.cloud.aiplatform.v1beta1.MigrationService.BatchMigrateResources].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchMigrateResourcesResponse = src.BatchMigrateResourcesResponse

// A job that uses a
// [Model][google.cloud.aiplatform.v1beta1.BatchPredictionJob.model] to produce
// predictions on multiple [input
// instances][google.cloud.aiplatform.v1beta1.BatchPredictionJob.input_config].
// If predictions for significant portion of the instances fail, the job may
// finish without attempting predictions for all remaining instances.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchPredictionJob = src.BatchPredictionJob

// Configures the input to
// [BatchPredictionJob][google.cloud.aiplatform.v1beta1.BatchPredictionJob].
// See
// [Model.supported_input_storage_formats][google.cloud.aiplatform.v1beta1.Model.supported_input_storage_formats]
// for Model's supported input formats, and how instances should be expressed
// via any of them.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchPredictionJob_InputConfig = src.BatchPredictionJob_InputConfig
type BatchPredictionJob_InputConfig_BigquerySource = src.BatchPredictionJob_InputConfig_BigquerySource
type BatchPredictionJob_InputConfig_GcsSource = src.BatchPredictionJob_InputConfig_GcsSource

// Configures the output of
// [BatchPredictionJob][google.cloud.aiplatform.v1beta1.BatchPredictionJob].
// See
// [Model.supported_output_storage_formats][google.cloud.aiplatform.v1beta1.Model.supported_output_storage_formats]
// for supported output formats, and how predictions are expressed via any of
// them.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchPredictionJob_OutputConfig = src.BatchPredictionJob_OutputConfig
type BatchPredictionJob_OutputConfig_BigqueryDestination = src.BatchPredictionJob_OutputConfig_BigqueryDestination
type BatchPredictionJob_OutputConfig_GcsDestination = src.BatchPredictionJob_OutputConfig_GcsDestination

// Further describes this job's output. Supplements
// [output_config][google.cloud.aiplatform.v1beta1.BatchPredictionJob.output_config].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchPredictionJob_OutputInfo = src.BatchPredictionJob_OutputInfo
type BatchPredictionJob_OutputInfo_BigqueryOutputDataset = src.BatchPredictionJob_OutputInfo_BigqueryOutputDataset
type BatchPredictionJob_OutputInfo_GcsOutputDirectory = src.BatchPredictionJob_OutputInfo_GcsOutputDirectory

// Details of operations that batch reads Feature values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadFeatureValuesOperationMetadata = src.BatchReadFeatureValuesOperationMetadata

// Request message for
// [FeaturestoreService.BatchReadFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.BatchReadFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadFeatureValuesRequest = src.BatchReadFeatureValuesRequest
type BatchReadFeatureValuesRequest_BigqueryReadInstances = src.BatchReadFeatureValuesRequest_BigqueryReadInstances
type BatchReadFeatureValuesRequest_CsvReadInstances = src.BatchReadFeatureValuesRequest_CsvReadInstances

// Selects Features of an EntityType to read values of and specifies read
// settings.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadFeatureValuesRequest_EntityTypeSpec = src.BatchReadFeatureValuesRequest_EntityTypeSpec

// Describe pass-through fields in read_instance source.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadFeatureValuesRequest_PassThroughField = src.BatchReadFeatureValuesRequest_PassThroughField

// Response message for
// [FeaturestoreService.BatchReadFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.BatchReadFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadFeatureValuesResponse = src.BatchReadFeatureValuesResponse

// Request message for
// [TensorboardService.BatchReadTensorboardTimeSeriesData][google.cloud.aiplatform.v1beta1.TensorboardService.BatchReadTensorboardTimeSeriesData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadTensorboardTimeSeriesDataRequest = src.BatchReadTensorboardTimeSeriesDataRequest

// Response message for
// [TensorboardService.BatchReadTensorboardTimeSeriesData][google.cloud.aiplatform.v1beta1.TensorboardService.BatchReadTensorboardTimeSeriesData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BatchReadTensorboardTimeSeriesDataResponse = src.BatchReadTensorboardTimeSeriesDataResponse

// The BigQuery location for the output content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BigQueryDestination = src.BigQueryDestination

// The BigQuery location for the input content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BigQuerySource = src.BigQuerySource

// Config for blur baseline. When enabled, a linear path from the maximally
// blurred image to the input image is created. Using a blurred baseline
// instead of zero (black image) is motivated by the BlurIG approach explained
// here: https://arxiv.org/abs/2004.03383
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BlurBaselineConfig = src.BlurBaselineConfig

// A list of boolean values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type BoolArray = src.BoolArray

// Request message for
// [JobService.CancelBatchPredictionJob][google.cloud.aiplatform.v1beta1.JobService.CancelBatchPredictionJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CancelBatchPredictionJobRequest = src.CancelBatchPredictionJobRequest

// Request message for
// [JobService.CancelCustomJob][google.cloud.aiplatform.v1beta1.JobService.CancelCustomJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CancelCustomJobRequest = src.CancelCustomJobRequest

// Request message for
// [JobService.CancelDataLabelingJob][google.cloud.aiplatform.v1beta1.JobService.CancelDataLabelingJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CancelDataLabelingJobRequest = src.CancelDataLabelingJobRequest

// Request message for
// [JobService.CancelHyperparameterTuningJob][google.cloud.aiplatform.v1beta1.JobService.CancelHyperparameterTuningJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CancelHyperparameterTuningJobRequest = src.CancelHyperparameterTuningJobRequest

// Request message for
// [PipelineService.CancelPipelineJob][google.cloud.aiplatform.v1beta1.PipelineService.CancelPipelineJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CancelPipelineJobRequest = src.CancelPipelineJobRequest

// Request message for
// [PipelineService.CancelTrainingPipeline][google.cloud.aiplatform.v1beta1.PipelineService.CancelTrainingPipeline].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CancelTrainingPipelineRequest = src.CancelTrainingPipelineRequest

// This message will be placed in the metadata field of a
// google.longrunning.Operation associated with a CheckTrialEarlyStoppingState
// request.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CheckTrialEarlyStoppingStateMetatdata = src.CheckTrialEarlyStoppingStateMetatdata

// Request message for
// [VizierService.CheckTrialEarlyStoppingState][google.cloud.aiplatform.v1beta1.VizierService.CheckTrialEarlyStoppingState].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CheckTrialEarlyStoppingStateRequest = src.CheckTrialEarlyStoppingStateRequest

// Response message for
// [VizierService.CheckTrialEarlyStoppingState][google.cloud.aiplatform.v1beta1.VizierService.CheckTrialEarlyStoppingState].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CheckTrialEarlyStoppingStateResponse = src.CheckTrialEarlyStoppingStateResponse

// Request message for
// [VizierService.CompleteTrial][google.cloud.aiplatform.v1beta1.VizierService.CompleteTrial].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CompleteTrialRequest = src.CompleteTrialRequest

// Success and error statistics of processing multiple entities (for example,
// DataItems or structured data rows) in batch.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CompletionStats = src.CompletionStats

// The Container Registry location for the container image.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ContainerRegistryDestination = src.ContainerRegistryDestination

// The spec of a Container.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ContainerSpec = src.ContainerSpec

// Instance of a general context.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Context = src.Context

// Request message for
// [MetadataService.CreateArtifact][google.cloud.aiplatform.v1beta1.MetadataService.CreateArtifact].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateArtifactRequest = src.CreateArtifactRequest

// Request message for
// [JobService.CreateBatchPredictionJob][google.cloud.aiplatform.v1beta1.JobService.CreateBatchPredictionJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateBatchPredictionJobRequest = src.CreateBatchPredictionJobRequest

// Request message for
// [MetadataService.CreateContext][google.cloud.aiplatform.v1beta1.MetadataService.CreateContext].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateContextRequest = src.CreateContextRequest

// Request message for
// [JobService.CreateCustomJob][google.cloud.aiplatform.v1beta1.JobService.CreateCustomJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateCustomJobRequest = src.CreateCustomJobRequest

// Request message for
// [JobService.CreateDataLabelingJob][google.cloud.aiplatform.v1beta1.JobService.CreateDataLabelingJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateDataLabelingJobRequest = src.CreateDataLabelingJobRequest

// Runtime operation information for
// [DatasetService.CreateDataset][google.cloud.aiplatform.v1beta1.DatasetService.CreateDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateDatasetOperationMetadata = src.CreateDatasetOperationMetadata

// Request message for
// [DatasetService.CreateDataset][google.cloud.aiplatform.v1beta1.DatasetService.CreateDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateDatasetRequest = src.CreateDatasetRequest

// Runtime operation information for CreateDeploymentResourcePool method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateDeploymentResourcePoolOperationMetadata = src.CreateDeploymentResourcePoolOperationMetadata

// Request message for CreateDeploymentResourcePool method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateDeploymentResourcePoolRequest = src.CreateDeploymentResourcePoolRequest

// Runtime operation information for
// [EndpointService.CreateEndpoint][google.cloud.aiplatform.v1beta1.EndpointService.CreateEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateEndpointOperationMetadata = src.CreateEndpointOperationMetadata

// Request message for
// [EndpointService.CreateEndpoint][google.cloud.aiplatform.v1beta1.EndpointService.CreateEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateEndpointRequest = src.CreateEndpointRequest

// Details of operations that perform create EntityType.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateEntityTypeOperationMetadata = src.CreateEntityTypeOperationMetadata

// Request message for
// [FeaturestoreService.CreateEntityType][google.cloud.aiplatform.v1beta1.FeaturestoreService.CreateEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateEntityTypeRequest = src.CreateEntityTypeRequest

// Request message for
// [MetadataService.CreateExecution][google.cloud.aiplatform.v1beta1.MetadataService.CreateExecution].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateExecutionRequest = src.CreateExecutionRequest

// Details of operations that perform create Feature.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateFeatureOperationMetadata = src.CreateFeatureOperationMetadata

// Request message for
// [FeaturestoreService.CreateFeature][google.cloud.aiplatform.v1beta1.FeaturestoreService.CreateFeature].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateFeatureRequest = src.CreateFeatureRequest

// Details of operations that perform create Featurestore.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateFeaturestoreOperationMetadata = src.CreateFeaturestoreOperationMetadata

// Request message for
// [FeaturestoreService.CreateFeaturestore][google.cloud.aiplatform.v1beta1.FeaturestoreService.CreateFeaturestore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateFeaturestoreRequest = src.CreateFeaturestoreRequest

// Request message for
// [JobService.CreateHyperparameterTuningJob][google.cloud.aiplatform.v1beta1.JobService.CreateHyperparameterTuningJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateHyperparameterTuningJobRequest = src.CreateHyperparameterTuningJobRequest

// Runtime operation information for
// [IndexEndpointService.CreateIndexEndpoint][google.cloud.aiplatform.v1beta1.IndexEndpointService.CreateIndexEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateIndexEndpointOperationMetadata = src.CreateIndexEndpointOperationMetadata

// Request message for
// [IndexEndpointService.CreateIndexEndpoint][google.cloud.aiplatform.v1beta1.IndexEndpointService.CreateIndexEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateIndexEndpointRequest = src.CreateIndexEndpointRequest

// Runtime operation information for
// [IndexService.CreateIndex][google.cloud.aiplatform.v1beta1.IndexService.CreateIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateIndexOperationMetadata = src.CreateIndexOperationMetadata

// Request message for
// [IndexService.CreateIndex][google.cloud.aiplatform.v1beta1.IndexService.CreateIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateIndexRequest = src.CreateIndexRequest

// Request message for
// [MetadataService.CreateMetadataSchema][google.cloud.aiplatform.v1beta1.MetadataService.CreateMetadataSchema].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateMetadataSchemaRequest = src.CreateMetadataSchemaRequest

// Details of operations that perform
// [MetadataService.CreateMetadataStore][google.cloud.aiplatform.v1beta1.MetadataService.CreateMetadataStore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateMetadataStoreOperationMetadata = src.CreateMetadataStoreOperationMetadata

// Request message for
// [MetadataService.CreateMetadataStore][google.cloud.aiplatform.v1beta1.MetadataService.CreateMetadataStore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateMetadataStoreRequest = src.CreateMetadataStoreRequest

// Request message for
// [JobService.CreateModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.CreateModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateModelDeploymentMonitoringJobRequest = src.CreateModelDeploymentMonitoringJobRequest

// Request message for
// [PipelineService.CreatePipelineJob][google.cloud.aiplatform.v1beta1.PipelineService.CreatePipelineJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreatePipelineJobRequest = src.CreatePipelineJobRequest

// Runtime operation information for
// [SpecialistPoolService.CreateSpecialistPool][google.cloud.aiplatform.v1beta1.SpecialistPoolService.CreateSpecialistPool].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateSpecialistPoolOperationMetadata = src.CreateSpecialistPoolOperationMetadata

// Request message for
// [SpecialistPoolService.CreateSpecialistPool][google.cloud.aiplatform.v1beta1.SpecialistPoolService.CreateSpecialistPool].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateSpecialistPoolRequest = src.CreateSpecialistPoolRequest

// Request message for
// [VizierService.CreateStudy][google.cloud.aiplatform.v1beta1.VizierService.CreateStudy].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateStudyRequest = src.CreateStudyRequest

// Request message for
// [TensorboardService.CreateTensorboardExperiment][google.cloud.aiplatform.v1beta1.TensorboardService.CreateTensorboardExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTensorboardExperimentRequest = src.CreateTensorboardExperimentRequest

// Details of operations that perform create Tensorboard.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTensorboardOperationMetadata = src.CreateTensorboardOperationMetadata

// Request message for
// [TensorboardService.CreateTensorboard][google.cloud.aiplatform.v1beta1.TensorboardService.CreateTensorboard].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTensorboardRequest = src.CreateTensorboardRequest

// Request message for
// [TensorboardService.CreateTensorboardRun][google.cloud.aiplatform.v1beta1.TensorboardService.CreateTensorboardRun].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTensorboardRunRequest = src.CreateTensorboardRunRequest

// Request message for
// [TensorboardService.CreateTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.CreateTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTensorboardTimeSeriesRequest = src.CreateTensorboardTimeSeriesRequest

// Request message for
// [PipelineService.CreateTrainingPipeline][google.cloud.aiplatform.v1beta1.PipelineService.CreateTrainingPipeline].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTrainingPipelineRequest = src.CreateTrainingPipelineRequest

// Request message for
// [VizierService.CreateTrial][google.cloud.aiplatform.v1beta1.VizierService.CreateTrial].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CreateTrialRequest = src.CreateTrialRequest

// The storage details for CSV output content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CsvDestination = src.CsvDestination

// The storage details for CSV input content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CsvSource = src.CsvSource

// Represents a job that runs custom workloads such as a Docker container or a
// Python package. A CustomJob can have multiple worker pools and each worker
// pool can have its own machine and input spec. A CustomJob will be cleaned up
// once the job enters terminal state (failed or succeeded).
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CustomJob = src.CustomJob

// Represents the spec of a CustomJob.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type CustomJobSpec = src.CustomJobSpec

// A piece of data in a Dataset. Could be an image, a video, a document or
// plain text.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DataItem = src.DataItem

// DataLabelingJob is used to trigger a human labeling job on unlabeled data
// from the following Dataset:
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DataLabelingJob = src.DataLabelingJob

// A collection of DataItems and Annotations on them.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Dataset = src.Dataset

// DatasetServiceClient is the client API for DatasetService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DatasetServiceClient = src.DatasetServiceClient

// DatasetServiceServer is the server API for DatasetService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DatasetServiceServer = src.DatasetServiceServer

// A description of resources that are dedicated to a DeployedModel, and that
// need a higher degree of manual configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DedicatedResources = src.DedicatedResources

// Request message for
// [MetadataService.DeleteArtifact][google.cloud.aiplatform.v1beta1.MetadataService.DeleteArtifact].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteArtifactRequest = src.DeleteArtifactRequest

// Request message for
// [JobService.DeleteBatchPredictionJob][google.cloud.aiplatform.v1beta1.JobService.DeleteBatchPredictionJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteBatchPredictionJobRequest = src.DeleteBatchPredictionJobRequest

// Request message for
// [MetadataService.DeleteContext][google.cloud.aiplatform.v1beta1.MetadataService.DeleteContext].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteContextRequest = src.DeleteContextRequest

// Request message for
// [JobService.DeleteCustomJob][google.cloud.aiplatform.v1beta1.JobService.DeleteCustomJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteCustomJobRequest = src.DeleteCustomJobRequest

// Request message for
// [JobService.DeleteDataLabelingJob][google.cloud.aiplatform.v1beta1.JobService.DeleteDataLabelingJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteDataLabelingJobRequest = src.DeleteDataLabelingJobRequest

// Request message for
// [DatasetService.DeleteDataset][google.cloud.aiplatform.v1beta1.DatasetService.DeleteDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteDatasetRequest = src.DeleteDatasetRequest

// Request message for DeleteDeploymentResourcePool method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteDeploymentResourcePoolRequest = src.DeleteDeploymentResourcePoolRequest

// Request message for
// [EndpointService.DeleteEndpoint][google.cloud.aiplatform.v1beta1.EndpointService.DeleteEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteEndpointRequest = src.DeleteEndpointRequest

// Request message for [FeaturestoreService.DeleteEntityTypes][].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteEntityTypeRequest = src.DeleteEntityTypeRequest

// Request message for
// [MetadataService.DeleteExecution][google.cloud.aiplatform.v1beta1.MetadataService.DeleteExecution].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteExecutionRequest = src.DeleteExecutionRequest

// Request message for
// [FeaturestoreService.DeleteFeature][google.cloud.aiplatform.v1beta1.FeaturestoreService.DeleteFeature].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeatureRequest = src.DeleteFeatureRequest

// Details of operations that delete Feature values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeatureValuesOperationMetadata = src.DeleteFeatureValuesOperationMetadata

// Request message for
// [FeaturestoreService.DeleteFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.DeleteFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeatureValuesRequest = src.DeleteFeatureValuesRequest

// Message to select entity. If an entity id is selected, all the feature
// values corresponding to the entity id will be deleted, including the
// entityId.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeatureValuesRequest_SelectEntity = src.DeleteFeatureValuesRequest_SelectEntity
type DeleteFeatureValuesRequest_SelectEntity_ = src.DeleteFeatureValuesRequest_SelectEntity_

// Message to select time range and feature. Values of the selected feature
// generated within an inclusive time range will be deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeatureValuesRequest_SelectTimeRangeAndFeature = src.DeleteFeatureValuesRequest_SelectTimeRangeAndFeature
type DeleteFeatureValuesRequest_SelectTimeRangeAndFeature_ = src.DeleteFeatureValuesRequest_SelectTimeRangeAndFeature_

// Response message for
// [FeaturestoreService.DeleteFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.DeleteFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeatureValuesResponse = src.DeleteFeatureValuesResponse

// Request message for
// [FeaturestoreService.DeleteFeaturestore][google.cloud.aiplatform.v1beta1.FeaturestoreService.DeleteFeaturestore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteFeaturestoreRequest = src.DeleteFeaturestoreRequest

// Request message for
// [JobService.DeleteHyperparameterTuningJob][google.cloud.aiplatform.v1beta1.JobService.DeleteHyperparameterTuningJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteHyperparameterTuningJobRequest = src.DeleteHyperparameterTuningJobRequest

// Request message for
// [IndexEndpointService.DeleteIndexEndpoint][google.cloud.aiplatform.v1beta1.IndexEndpointService.DeleteIndexEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteIndexEndpointRequest = src.DeleteIndexEndpointRequest

// Request message for
// [IndexService.DeleteIndex][google.cloud.aiplatform.v1beta1.IndexService.DeleteIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteIndexRequest = src.DeleteIndexRequest

// Details of operations that perform
// [MetadataService.DeleteMetadataStore][google.cloud.aiplatform.v1beta1.MetadataService.DeleteMetadataStore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteMetadataStoreOperationMetadata = src.DeleteMetadataStoreOperationMetadata

// Request message for
// [MetadataService.DeleteMetadataStore][google.cloud.aiplatform.v1beta1.MetadataService.DeleteMetadataStore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteMetadataStoreRequest = src.DeleteMetadataStoreRequest

// Request message for
// [JobService.DeleteModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.DeleteModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteModelDeploymentMonitoringJobRequest = src.DeleteModelDeploymentMonitoringJobRequest

// Request message for
// [ModelService.DeleteModel][google.cloud.aiplatform.v1beta1.ModelService.DeleteModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteModelRequest = src.DeleteModelRequest

// Request message for
// [ModelService.DeleteModelVersion][google.cloud.aiplatform.v1beta1.ModelService.DeleteModelVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteModelVersionRequest = src.DeleteModelVersionRequest

// Details of operations that perform deletes of any entities.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteOperationMetadata = src.DeleteOperationMetadata

// Request message for
// [PipelineService.DeletePipelineJob][google.cloud.aiplatform.v1beta1.PipelineService.DeletePipelineJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeletePipelineJobRequest = src.DeletePipelineJobRequest

// Request message for
// [SpecialistPoolService.DeleteSpecialistPool][google.cloud.aiplatform.v1beta1.SpecialistPoolService.DeleteSpecialistPool].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteSpecialistPoolRequest = src.DeleteSpecialistPoolRequest

// Request message for
// [VizierService.DeleteStudy][google.cloud.aiplatform.v1beta1.VizierService.DeleteStudy].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteStudyRequest = src.DeleteStudyRequest

// Request message for
// [TensorboardService.DeleteTensorboardExperiment][google.cloud.aiplatform.v1beta1.TensorboardService.DeleteTensorboardExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteTensorboardExperimentRequest = src.DeleteTensorboardExperimentRequest

// Request message for
// [TensorboardService.DeleteTensorboard][google.cloud.aiplatform.v1beta1.TensorboardService.DeleteTensorboard].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteTensorboardRequest = src.DeleteTensorboardRequest

// Request message for
// [TensorboardService.DeleteTensorboardRun][google.cloud.aiplatform.v1beta1.TensorboardService.DeleteTensorboardRun].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteTensorboardRunRequest = src.DeleteTensorboardRunRequest

// Request message for
// [TensorboardService.DeleteTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.DeleteTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteTensorboardTimeSeriesRequest = src.DeleteTensorboardTimeSeriesRequest

// Request message for
// [PipelineService.DeleteTrainingPipeline][google.cloud.aiplatform.v1beta1.PipelineService.DeleteTrainingPipeline].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteTrainingPipelineRequest = src.DeleteTrainingPipelineRequest

// Request message for
// [VizierService.DeleteTrial][google.cloud.aiplatform.v1beta1.VizierService.DeleteTrial].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeleteTrialRequest = src.DeleteTrialRequest

// Runtime operation information for
// [IndexEndpointService.DeployIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.DeployIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployIndexOperationMetadata = src.DeployIndexOperationMetadata

// Request message for
// [IndexEndpointService.DeployIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.DeployIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployIndexRequest = src.DeployIndexRequest

// Response message for
// [IndexEndpointService.DeployIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.DeployIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployIndexResponse = src.DeployIndexResponse

// Runtime operation information for
// [EndpointService.DeployModel][google.cloud.aiplatform.v1beta1.EndpointService.DeployModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployModelOperationMetadata = src.DeployModelOperationMetadata

// Request message for
// [EndpointService.DeployModel][google.cloud.aiplatform.v1beta1.EndpointService.DeployModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployModelRequest = src.DeployModelRequest

// Response message for
// [EndpointService.DeployModel][google.cloud.aiplatform.v1beta1.EndpointService.DeployModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployModelResponse = src.DeployModelResponse

// A deployment of an Index. IndexEndpoints contain one or more
// DeployedIndexes.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployedIndex = src.DeployedIndex

// Used to set up the auth on the DeployedIndex's private endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployedIndexAuthConfig = src.DeployedIndexAuthConfig

// Configuration for an authentication provider, including support for [JSON
// Web Token
// (JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployedIndexAuthConfig_AuthProvider = src.DeployedIndexAuthConfig_AuthProvider

// Points to a DeployedIndex.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployedIndexRef = src.DeployedIndexRef

// A deployment of a Model. Endpoints contain one or more DeployedModels.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployedModel = src.DeployedModel

// Points to a DeployedModel.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeployedModelRef = src.DeployedModelRef
type DeployedModel_AutomaticResources = src.DeployedModel_AutomaticResources
type DeployedModel_DedicatedResources = src.DeployedModel_DedicatedResources
type DeployedModel_SharedResources = src.DeployedModel_SharedResources

// A description of resources that can be shared by multiple DeployedModels,
// whose underlying specification consists of a DedicatedResources.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeploymentResourcePool = src.DeploymentResourcePool

// DeploymentResourcePoolServiceClient is the client API for
// DeploymentResourcePoolService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeploymentResourcePoolServiceClient = src.DeploymentResourcePoolServiceClient

// DeploymentResourcePoolServiceServer is the server API for
// DeploymentResourcePoolService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DeploymentResourcePoolServiceServer = src.DeploymentResourcePoolServiceServer
type DestinationFeatureSetting = src.DestinationFeatureSetting

// Represents the spec of disk options.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DiskSpec = src.DiskSpec

// A list of double values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type DoubleArray = src.DoubleArray

// Represents a customer-managed encryption key spec that can be applied to a
// top-level resource.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type EncryptionSpec = src.EncryptionSpec

// Models are deployed into it, and afterwards Endpoint is called to obtain
// predictions and explanations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Endpoint = src.Endpoint

// EndpointServiceClient is the client API for EndpointService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type EndpointServiceClient = src.EndpointServiceClient

// EndpointServiceServer is the server API for EndpointService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type EndpointServiceServer = src.EndpointServiceServer

// Selector for entityId. Getting ids from the given source.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type EntityIdSelector = src.EntityIdSelector
type EntityIdSelector_CsvSource = src.EntityIdSelector_CsvSource

// An entity type is a type of object in a system that needs to be modeled and
// have stored information about. For example, driver is an entity type, and
// driver0 is an instance of an entity type driver.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type EntityType = src.EntityType

// Represents an environment variable present in a Container or Python Module.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type EnvVar = src.EnvVar

// An edge describing the relationship between an Artifact and an Execution in
// a lineage graph.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Event = src.Event

// Describes whether an Event's Artifact is the Execution's input or output.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Event_Type = src.Event_Type

// Example-based explainability that returns the nearest neighbors from the
// provided dataset.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Examples = src.Examples

// Overrides for example-based explanations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExamplesOverride = src.ExamplesOverride

// Data format enum.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExamplesOverride_DataFormat = src.ExamplesOverride_DataFormat

// Restrictions namespace for example-based explanations overrides.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExamplesRestrictionsNamespace = src.ExamplesRestrictionsNamespace
type Examples_NearestNeighborSearchConfig = src.Examples_NearestNeighborSearchConfig
type Examples_Presets = src.Examples_Presets

// Instance of a general execution.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Execution = src.Execution

// Describes the state of the Execution.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Execution_State = src.Execution_State

// Request message for
// [PredictionService.Explain][google.cloud.aiplatform.v1beta1.PredictionService.Explain].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplainRequest = src.ExplainRequest

// Response message for
// [PredictionService.Explain][google.cloud.aiplatform.v1beta1.PredictionService.Explain].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplainResponse = src.ExplainResponse

// Explanation of a prediction (provided in
// [PredictResponse.predictions][google.cloud.aiplatform.v1beta1.PredictResponse.predictions])
// produced by the Model on a given
// [instance][google.cloud.aiplatform.v1beta1.ExplainRequest.instances].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Explanation = src.Explanation

// Metadata describing the Model's input and output for explanation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata = src.ExplanationMetadata

// The
// [ExplanationMetadata][google.cloud.aiplatform.v1beta1.ExplanationMetadata]
// entries that can be overridden at [online
// explanation][google.cloud.aiplatform.v1beta1.PredictionService.Explain]
// time.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadataOverride = src.ExplanationMetadataOverride

// The [input
// metadata][google.cloud.aiplatform.v1beta1.ExplanationMetadata.InputMetadata]
// entries to be overridden.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadataOverride_InputMetadataOverride = src.ExplanationMetadataOverride_InputMetadataOverride

// Metadata of the input of a feature. Fields other than
// [InputMetadata.input_baselines][google.cloud.aiplatform.v1beta1.ExplanationMetadata.InputMetadata.input_baselines]
// are applicable only for Models that are using Vertex AI-provided images for
// Tensorflow.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata = src.ExplanationMetadata_InputMetadata

// Defines how a feature is encoded. Defaults to IDENTITY.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_Encoding = src.ExplanationMetadata_InputMetadata_Encoding

// Domain details of the input feature value. Provides numeric information
// about the feature, such as its range (min, max). If the feature has been
// pre-processed, for example with z-scoring, then it provides information
// about how to recover the original feature. For example, if the input feature
// is an image and it has been pre-processed to obtain 0-mean and stddev = 1
// values, then original_mean, and original_stddev refer to the mean and stddev
// of the original feature (e.g. image tensor) from which input feature (with
// mean = 0 and stddev = 1) was obtained.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_FeatureValueDomain = src.ExplanationMetadata_InputMetadata_FeatureValueDomain

// Visualization configurations for image explanation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_Visualization = src.ExplanationMetadata_InputMetadata_Visualization

// The color scheme used for highlighting areas.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_Visualization_ColorMap = src.ExplanationMetadata_InputMetadata_Visualization_ColorMap

// How the original image is displayed in the visualization.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_Visualization_OverlayType = src.ExplanationMetadata_InputMetadata_Visualization_OverlayType

// Whether to only highlight pixels with positive contributions, negative or
// both. Defaults to POSITIVE.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_Visualization_Polarity = src.ExplanationMetadata_InputMetadata_Visualization_Polarity

// Type of the image visualization. Only applicable to [Integrated Gradients
// attribution][google.cloud.aiplatform.v1beta1.ExplanationParameters.integrated_gradients_attribution].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_InputMetadata_Visualization_Type = src.ExplanationMetadata_InputMetadata_Visualization_Type

// Metadata of the prediction output to be explained.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationMetadata_OutputMetadata = src.ExplanationMetadata_OutputMetadata
type ExplanationMetadata_OutputMetadata_DisplayNameMappingKey = src.ExplanationMetadata_OutputMetadata_DisplayNameMappingKey
type ExplanationMetadata_OutputMetadata_IndexDisplayNameMapping = src.ExplanationMetadata_OutputMetadata_IndexDisplayNameMapping

// Parameters to configure explaining for Model's predictions.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationParameters = src.ExplanationParameters
type ExplanationParameters_Examples = src.ExplanationParameters_Examples
type ExplanationParameters_IntegratedGradientsAttribution = src.ExplanationParameters_IntegratedGradientsAttribution
type ExplanationParameters_SampledShapleyAttribution = src.ExplanationParameters_SampledShapleyAttribution
type ExplanationParameters_XraiAttribution = src.ExplanationParameters_XraiAttribution

// Specification of Model explanation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationSpec = src.ExplanationSpec

// The [ExplanationSpec][google.cloud.aiplatform.v1beta1.ExplanationSpec]
// entries that can be overridden at [online
// explanation][google.cloud.aiplatform.v1beta1.PredictionService.Explain]
// time.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExplanationSpecOverride = src.ExplanationSpecOverride

// Describes what part of the Dataset is to be exported, the destination of
// the export and how to export.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportDataConfig = src.ExportDataConfig
type ExportDataConfig_GcsDestination = src.ExportDataConfig_GcsDestination

// Runtime operation information for
// [DatasetService.ExportData][google.cloud.aiplatform.v1beta1.DatasetService.ExportData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportDataOperationMetadata = src.ExportDataOperationMetadata

// Request message for
// [DatasetService.ExportData][google.cloud.aiplatform.v1beta1.DatasetService.ExportData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportDataRequest = src.ExportDataRequest

// Response message for
// [DatasetService.ExportData][google.cloud.aiplatform.v1beta1.DatasetService.ExportData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportDataResponse = src.ExportDataResponse

// Details of operations that exports Features values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportFeatureValuesOperationMetadata = src.ExportFeatureValuesOperationMetadata

// Request message for
// [FeaturestoreService.ExportFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.ExportFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportFeatureValuesRequest = src.ExportFeatureValuesRequest

// Describes exporting all historical Feature values of all entities of the
// EntityType between [start_time, end_time].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportFeatureValuesRequest_FullExport = src.ExportFeatureValuesRequest_FullExport
type ExportFeatureValuesRequest_FullExport_ = src.ExportFeatureValuesRequest_FullExport_

// Describes exporting the latest Feature values of all entities of the
// EntityType between [start_time, snapshot_time].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportFeatureValuesRequest_SnapshotExport = src.ExportFeatureValuesRequest_SnapshotExport
type ExportFeatureValuesRequest_SnapshotExport_ = src.ExportFeatureValuesRequest_SnapshotExport_

// Response message for
// [FeaturestoreService.ExportFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.ExportFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportFeatureValuesResponse = src.ExportFeatureValuesResponse

// Details of
// [ModelService.ExportModel][google.cloud.aiplatform.v1beta1.ModelService.ExportModel]
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportModelOperationMetadata = src.ExportModelOperationMetadata

// Further describes the output of the ExportModel. Supplements
// [ExportModelRequest.OutputConfig][google.cloud.aiplatform.v1beta1.ExportModelRequest.OutputConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportModelOperationMetadata_OutputInfo = src.ExportModelOperationMetadata_OutputInfo

// Request message for
// [ModelService.ExportModel][google.cloud.aiplatform.v1beta1.ModelService.ExportModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportModelRequest = src.ExportModelRequest

// Output configuration for the Model export.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportModelRequest_OutputConfig = src.ExportModelRequest_OutputConfig

// Response message of
// [ModelService.ExportModel][google.cloud.aiplatform.v1beta1.ModelService.ExportModel]
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportModelResponse = src.ExportModelResponse

// Request message for
// [TensorboardService.ExportTensorboardTimeSeriesData][google.cloud.aiplatform.v1beta1.TensorboardService.ExportTensorboardTimeSeriesData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportTensorboardTimeSeriesDataRequest = src.ExportTensorboardTimeSeriesDataRequest

// Response message for
// [TensorboardService.ExportTensorboardTimeSeriesData][google.cloud.aiplatform.v1beta1.TensorboardService.ExportTensorboardTimeSeriesData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ExportTensorboardTimeSeriesDataResponse = src.ExportTensorboardTimeSeriesDataResponse

// Feature Metadata information that describes an attribute of an entity type.
// For example, apple is an entity type, and color is a feature that describes
// apple.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Feature = src.Feature

// Noise sigma by features. Noise sigma represents the standard deviation of
// the gaussian kernel that will be used to add noise to interpolated inputs
// prior to computing gradients.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureNoiseSigma = src.FeatureNoiseSigma

// Noise sigma for a single feature.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureNoiseSigma_NoiseSigmaForFeature = src.FeatureNoiseSigma_NoiseSigmaForFeature

// Selector for Features of an EntityType.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureSelector = src.FeatureSelector

// Stats and Anomaly generated at specific timestamp for specific Feature. The
// start_time and end_time are used to define the time range of the dataset
// that current stats belongs to, e.g. prediction traffic is bucketed into
// prediction datasets by time window. If the Dataset is not defined by time
// window, start_time = end_time. Timestamp of the stats and anomalies always
// refers to end_time. Raw stats and anomalies are stored in stats_uri or
// anomaly_uri in the tensorflow defined protos. Field data_stats contains
// almost identical information with the raw stats in Vertex AI defined proto,
// for UI to display.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureStatsAnomaly = src.FeatureStatsAnomaly

// Value for a feature.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureValue = src.FeatureValue

// A destination location for Feature values and format.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureValueDestination = src.FeatureValueDestination
type FeatureValueDestination_BigqueryDestination = src.FeatureValueDestination_BigqueryDestination
type FeatureValueDestination_CsvDestination = src.FeatureValueDestination_CsvDestination
type FeatureValueDestination_TfrecordDestination = src.FeatureValueDestination_TfrecordDestination

// Container for list of values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureValueList = src.FeatureValueList
type FeatureValue_BoolArrayValue = src.FeatureValue_BoolArrayValue
type FeatureValue_BoolValue = src.FeatureValue_BoolValue
type FeatureValue_BytesValue = src.FeatureValue_BytesValue
type FeatureValue_DoubleArrayValue = src.FeatureValue_DoubleArrayValue
type FeatureValue_DoubleValue = src.FeatureValue_DoubleValue
type FeatureValue_Int64ArrayValue = src.FeatureValue_Int64ArrayValue
type FeatureValue_Int64Value = src.FeatureValue_Int64Value

// Metadata of feature value.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeatureValue_Metadata = src.FeatureValue_Metadata
type FeatureValue_StringArrayValue = src.FeatureValue_StringArrayValue
type FeatureValue_StringValue = src.FeatureValue_StringValue

// A list of historical [Snapshot
// Analysis][FeaturestoreMonitoringConfig.SnapshotAnalysis] or [Import Feature
// Analysis] [FeaturestoreMonitoringConfig.ImportFeatureAnalysis] stats
// requested by user, sorted by
// [FeatureStatsAnomaly.start_time][google.cloud.aiplatform.v1beta1.FeatureStatsAnomaly.start_time]
// descending.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Feature_MonitoringStatsAnomaly = src.Feature_MonitoringStatsAnomaly

// If the objective in the request is both Import Feature Analysis and
// Snapshot Analysis, this objective could be one of them. Otherwise, this
// objective should be the same as the objective in the request.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Feature_MonitoringStatsAnomaly_Objective = src.Feature_MonitoringStatsAnomaly_Objective

// An enum representing the value type of a feature.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Feature_ValueType = src.Feature_ValueType

// Vertex AI Feature Store provides a centralized repository for organizing,
// storing, and serving ML features. The Featurestore is a top-level container
// for your features and their values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Featurestore = src.Featurestore

// Configuration of how features in Featurestore are monitored.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreMonitoringConfig = src.FeaturestoreMonitoringConfig

// Configuration of the Featurestore's ImportFeature Analysis Based
// Monitoring. This type of analysis generates statistics for values of each
// Feature imported by every [ImportFeatureValues][] operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreMonitoringConfig_ImportFeaturesAnalysis = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis

// Defines the baseline to do anomaly detection for feature values imported by
// each [ImportFeatureValues][] operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_Baseline

// The state defines whether to enable ImportFeature analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State = src.FeaturestoreMonitoringConfig_ImportFeaturesAnalysis_State

// Configuration of the Featurestore's Snapshot Analysis Based Monitoring.
// This type of analysis generates statistics for each Feature based on a
// snapshot of the latest feature value of each entities every
// monitoring_interval.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreMonitoringConfig_SnapshotAnalysis = src.FeaturestoreMonitoringConfig_SnapshotAnalysis

// The config for Featurestore Monitoring threshold.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreMonitoringConfig_ThresholdConfig = src.FeaturestoreMonitoringConfig_ThresholdConfig
type FeaturestoreMonitoringConfig_ThresholdConfig_Value = src.FeaturestoreMonitoringConfig_ThresholdConfig_Value

// FeaturestoreOnlineServingServiceClient is the client API for
// FeaturestoreOnlineServingService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreOnlineServingServiceClient = src.FeaturestoreOnlineServingServiceClient

// FeaturestoreOnlineServingServiceServer is the server API for
// FeaturestoreOnlineServingService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreOnlineServingServiceServer = src.FeaturestoreOnlineServingServiceServer
type FeaturestoreOnlineServingService_StreamingReadFeatureValuesClient = src.FeaturestoreOnlineServingService_StreamingReadFeatureValuesClient
type FeaturestoreOnlineServingService_StreamingReadFeatureValuesServer = src.FeaturestoreOnlineServingService_StreamingReadFeatureValuesServer

// FeaturestoreServiceClient is the client API for FeaturestoreService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreServiceClient = src.FeaturestoreServiceClient

// FeaturestoreServiceServer is the server API for FeaturestoreService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FeaturestoreServiceServer = src.FeaturestoreServiceServer

// OnlineServingConfig specifies the details for provisioning online serving
// resources.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Featurestore_OnlineServingConfig = src.Featurestore_OnlineServingConfig

// Online serving scaling configuration. If min_node_count and max_node_count
// are set to the same value, the cluster will be configured with the fixed
// number of node (no auto-scaling).
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Featurestore_OnlineServingConfig_Scaling = src.Featurestore_OnlineServingConfig_Scaling

// Possible states a featurestore can have.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Featurestore_State = src.Featurestore_State

// Assigns input data to training, validation, and test sets based on the
// given filters, data pieces not matched by any filter are ignored. Currently
// only supported for Datasets containing DataItems. If any of the filters in
// this message are to match nothing, then they can be set as '-' (the minus
// sign). Supported only for unstructured Datasets.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FilterSplit = src.FilterSplit

// Assigns the input data to training, validation, and test sets as per the
// given fractions. Any of `training_fraction`, `validation_fraction` and
// `test_fraction` may optionally be provided, they must sum to up to 1. If the
// provided ones sum to less than 1, the remainder is assigned to sets as
// decided by Vertex AI. If none of the fractions are set, by default roughly
// 80% of data is used for training, 10% for validation, and 10% for test.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type FractionSplit = src.FractionSplit

// The Google Cloud Storage location where the output is to be written to.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GcsDestination = src.GcsDestination

// The Google Cloud Storage location for the input content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GcsSource = src.GcsSource

// Generic Metadata shared by all operations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GenericOperationMetadata = src.GenericOperationMetadata

// Request message for
// [DatasetService.GetAnnotationSpec][google.cloud.aiplatform.v1beta1.DatasetService.GetAnnotationSpec].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetAnnotationSpecRequest = src.GetAnnotationSpecRequest

// Request message for
// [MetadataService.GetArtifact][google.cloud.aiplatform.v1beta1.MetadataService.GetArtifact].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetArtifactRequest = src.GetArtifactRequest

// Request message for
// [JobService.GetBatchPredictionJob][google.cloud.aiplatform.v1beta1.JobService.GetBatchPredictionJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetBatchPredictionJobRequest = src.GetBatchPredictionJobRequest

// Request message for
// [MetadataService.GetContext][google.cloud.aiplatform.v1beta1.MetadataService.GetContext].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetContextRequest = src.GetContextRequest

// Request message for
// [JobService.GetCustomJob][google.cloud.aiplatform.v1beta1.JobService.GetCustomJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetCustomJobRequest = src.GetCustomJobRequest

// Request message for
// [JobService.GetDataLabelingJob][google.cloud.aiplatform.v1beta1.JobService.GetDataLabelingJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetDataLabelingJobRequest = src.GetDataLabelingJobRequest

// Request message for
// [DatasetService.GetDataset][google.cloud.aiplatform.v1beta1.DatasetService.GetDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetDatasetRequest = src.GetDatasetRequest

// Request message for GetDeploymentResourcePool method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetDeploymentResourcePoolRequest = src.GetDeploymentResourcePoolRequest

// Request message for
// [EndpointService.GetEndpoint][google.cloud.aiplatform.v1beta1.EndpointService.GetEndpoint]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetEndpointRequest = src.GetEndpointRequest

// Request message for
// [FeaturestoreService.GetEntityType][google.cloud.aiplatform.v1beta1.FeaturestoreService.GetEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetEntityTypeRequest = src.GetEntityTypeRequest

// Request message for
// [MetadataService.GetExecution][google.cloud.aiplatform.v1beta1.MetadataService.GetExecution].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetExecutionRequest = src.GetExecutionRequest

// Request message for
// [FeaturestoreService.GetFeature][google.cloud.aiplatform.v1beta1.FeaturestoreService.GetFeature].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetFeatureRequest = src.GetFeatureRequest

// Request message for
// [FeaturestoreService.GetFeaturestore][google.cloud.aiplatform.v1beta1.FeaturestoreService.GetFeaturestore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetFeaturestoreRequest = src.GetFeaturestoreRequest

// Request message for
// [JobService.GetHyperparameterTuningJob][google.cloud.aiplatform.v1beta1.JobService.GetHyperparameterTuningJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetHyperparameterTuningJobRequest = src.GetHyperparameterTuningJobRequest

// Request message for
// [IndexEndpointService.GetIndexEndpoint][google.cloud.aiplatform.v1beta1.IndexEndpointService.GetIndexEndpoint]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetIndexEndpointRequest = src.GetIndexEndpointRequest

// Request message for
// [IndexService.GetIndex][google.cloud.aiplatform.v1beta1.IndexService.GetIndex]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetIndexRequest = src.GetIndexRequest

// Request message for
// [MetadataService.GetMetadataSchema][google.cloud.aiplatform.v1beta1.MetadataService.GetMetadataSchema].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetMetadataSchemaRequest = src.GetMetadataSchemaRequest

// Request message for
// [MetadataService.GetMetadataStore][google.cloud.aiplatform.v1beta1.MetadataService.GetMetadataStore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetMetadataStoreRequest = src.GetMetadataStoreRequest

// Request message for
// [JobService.GetModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.GetModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetModelDeploymentMonitoringJobRequest = src.GetModelDeploymentMonitoringJobRequest

// Request message for
// [ModelService.GetModelEvaluation][google.cloud.aiplatform.v1beta1.ModelService.GetModelEvaluation].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetModelEvaluationRequest = src.GetModelEvaluationRequest

// Request message for
// [ModelService.GetModelEvaluationSlice][google.cloud.aiplatform.v1beta1.ModelService.GetModelEvaluationSlice].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetModelEvaluationSliceRequest = src.GetModelEvaluationSliceRequest

// Request message for
// [ModelService.GetModel][google.cloud.aiplatform.v1beta1.ModelService.GetModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetModelRequest = src.GetModelRequest

// Request message for
// [PipelineService.GetPipelineJob][google.cloud.aiplatform.v1beta1.PipelineService.GetPipelineJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetPipelineJobRequest = src.GetPipelineJobRequest

// Request message for
// [SpecialistPoolService.GetSpecialistPool][google.cloud.aiplatform.v1beta1.SpecialistPoolService.GetSpecialistPool].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetSpecialistPoolRequest = src.GetSpecialistPoolRequest

// Request message for
// [VizierService.GetStudy][google.cloud.aiplatform.v1beta1.VizierService.GetStudy].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetStudyRequest = src.GetStudyRequest

// Request message for
// [TensorboardService.GetTensorboardExperiment][google.cloud.aiplatform.v1beta1.TensorboardService.GetTensorboardExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetTensorboardExperimentRequest = src.GetTensorboardExperimentRequest

// Request message for
// [TensorboardService.GetTensorboard][google.cloud.aiplatform.v1beta1.TensorboardService.GetTensorboard].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetTensorboardRequest = src.GetTensorboardRequest

// Request message for
// [TensorboardService.GetTensorboardRun][google.cloud.aiplatform.v1beta1.TensorboardService.GetTensorboardRun].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetTensorboardRunRequest = src.GetTensorboardRunRequest

// Request message for
// [TensorboardService.GetTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.GetTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetTensorboardTimeSeriesRequest = src.GetTensorboardTimeSeriesRequest

// Request message for
// [PipelineService.GetTrainingPipeline][google.cloud.aiplatform.v1beta1.PipelineService.GetTrainingPipeline].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetTrainingPipelineRequest = src.GetTrainingPipelineRequest

// Request message for
// [VizierService.GetTrial][google.cloud.aiplatform.v1beta1.VizierService.GetTrial].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type GetTrialRequest = src.GetTrialRequest

// Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study
// specification and multiple CustomJobs with identical CustomJob
// specification.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type HyperparameterTuningJob = src.HyperparameterTuningJob

// Matcher for Features of an EntityType by Feature ID.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IdMatcher = src.IdMatcher

// Describes the location from where we import data into a Dataset, together
// with the labels that will be applied to the DataItems and the Annotations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportDataConfig = src.ImportDataConfig
type ImportDataConfig_GcsSource = src.ImportDataConfig_GcsSource

// Runtime operation information for
// [DatasetService.ImportData][google.cloud.aiplatform.v1beta1.DatasetService.ImportData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportDataOperationMetadata = src.ImportDataOperationMetadata

// Request message for
// [DatasetService.ImportData][google.cloud.aiplatform.v1beta1.DatasetService.ImportData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportDataRequest = src.ImportDataRequest

// Response message for
// [DatasetService.ImportData][google.cloud.aiplatform.v1beta1.DatasetService.ImportData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportDataResponse = src.ImportDataResponse

// Details of operations that perform import Feature values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportFeatureValuesOperationMetadata = src.ImportFeatureValuesOperationMetadata

// Request message for
// [FeaturestoreService.ImportFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.ImportFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportFeatureValuesRequest = src.ImportFeatureValuesRequest
type ImportFeatureValuesRequest_AvroSource = src.ImportFeatureValuesRequest_AvroSource
type ImportFeatureValuesRequest_BigquerySource = src.ImportFeatureValuesRequest_BigquerySource
type ImportFeatureValuesRequest_CsvSource = src.ImportFeatureValuesRequest_CsvSource

// Defines the Feature value(s) to import.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportFeatureValuesRequest_FeatureSpec = src.ImportFeatureValuesRequest_FeatureSpec
type ImportFeatureValuesRequest_FeatureTime = src.ImportFeatureValuesRequest_FeatureTime
type ImportFeatureValuesRequest_FeatureTimeField = src.ImportFeatureValuesRequest_FeatureTimeField

// Response message for
// [FeaturestoreService.ImportFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreService.ImportFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportFeatureValuesResponse = src.ImportFeatureValuesResponse

// Request message for
// [ModelService.ImportModelEvaluation][google.cloud.aiplatform.v1beta1.ModelService.ImportModelEvaluation]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ImportModelEvaluationRequest = src.ImportModelEvaluationRequest

// A representation of a collection of database items organized in a way that
// allows for approximate nearest neighbor (a.k.a ANN) algorithms search.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Index = src.Index

// A datapoint of Index.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexDatapoint = src.IndexDatapoint

// Crowding tag is a constraint on a neighbor list produced by nearest
// neighbor search requiring that no more than some value k' of the k neighbors
// returned have the same value of crowding_attribute.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexDatapoint_CrowdingTag = src.IndexDatapoint_CrowdingTag

// Restriction of a datapoint which describe its attributes(tokens) from each
// of several attribute categories(namespaces).
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexDatapoint_Restriction = src.IndexDatapoint_Restriction

// Indexes are deployed into it. An IndexEndpoint can have multiple
// DeployedIndexes.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexEndpoint = src.IndexEndpoint

// IndexEndpointServiceClient is the client API for IndexEndpointService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexEndpointServiceClient = src.IndexEndpointServiceClient

// IndexEndpointServiceServer is the server API for IndexEndpointService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexEndpointServiceServer = src.IndexEndpointServiceServer

// IndexPrivateEndpoints proto is used to provide paths for users to send
// requests via private endpoints (e.g. private service access, private service
// connect). To send request via private service access, use
// match_grpc_address. To send request via private service connect, use
// service_attachment.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexPrivateEndpoints = src.IndexPrivateEndpoints

// IndexServiceClient is the client API for IndexService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexServiceClient = src.IndexServiceClient

// IndexServiceServer is the server API for IndexService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexServiceServer = src.IndexServiceServer

// Stats of the Index.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IndexStats = src.IndexStats

// The update method of an Index.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Index_IndexUpdateMethod = src.Index_IndexUpdateMethod

// Specifies Vertex AI owned input data to be used for training, and possibly
// evaluating, the Model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type InputDataConfig = src.InputDataConfig
type InputDataConfig_BigqueryDestination = src.InputDataConfig_BigqueryDestination
type InputDataConfig_FilterSplit = src.InputDataConfig_FilterSplit
type InputDataConfig_FractionSplit = src.InputDataConfig_FractionSplit
type InputDataConfig_GcsDestination = src.InputDataConfig_GcsDestination
type InputDataConfig_PredefinedSplit = src.InputDataConfig_PredefinedSplit
type InputDataConfig_StratifiedSplit = src.InputDataConfig_StratifiedSplit
type InputDataConfig_TimestampSplit = src.InputDataConfig_TimestampSplit

// A list of int64 values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Int64Array = src.Int64Array

// An attribution method that computes the Aumann-Shapley value taking
// advantage of the model's fully differentiable structure. Refer to this paper
// for more details: https://arxiv.org/abs/1703.01365
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type IntegratedGradientsAttribution = src.IntegratedGradientsAttribution

// JobServiceClient is the client API for JobService service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type JobServiceClient = src.JobServiceClient

// JobServiceServer is the server API for JobService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type JobServiceServer = src.JobServiceServer

// Describes the state of a job.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type JobState = src.JobState

// A subgraph of the overall lineage graph. Event edges connect Artifact and
// Execution nodes.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type LineageSubgraph = src.LineageSubgraph

// Request message for
// [DatasetService.ListAnnotations][google.cloud.aiplatform.v1beta1.DatasetService.ListAnnotations].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListAnnotationsRequest = src.ListAnnotationsRequest

// Response message for
// [DatasetService.ListAnnotations][google.cloud.aiplatform.v1beta1.DatasetService.ListAnnotations].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListAnnotationsResponse = src.ListAnnotationsResponse

// Request message for
// [MetadataService.ListArtifacts][google.cloud.aiplatform.v1beta1.MetadataService.ListArtifacts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListArtifactsRequest = src.ListArtifactsRequest

// Response message for
// [MetadataService.ListArtifacts][google.cloud.aiplatform.v1beta1.MetadataService.ListArtifacts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListArtifactsResponse = src.ListArtifactsResponse

// Request message for
// [JobService.ListBatchPredictionJobs][google.cloud.aiplatform.v1beta1.JobService.ListBatchPredictionJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListBatchPredictionJobsRequest = src.ListBatchPredictionJobsRequest

// Response message for
// [JobService.ListBatchPredictionJobs][google.cloud.aiplatform.v1beta1.JobService.ListBatchPredictionJobs]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListBatchPredictionJobsResponse = src.ListBatchPredictionJobsResponse

// Request message for
// [MetadataService.ListContexts][google.cloud.aiplatform.v1beta1.MetadataService.ListContexts]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListContextsRequest = src.ListContextsRequest

// Response message for
// [MetadataService.ListContexts][google.cloud.aiplatform.v1beta1.MetadataService.ListContexts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListContextsResponse = src.ListContextsResponse

// Request message for
// [JobService.ListCustomJobs][google.cloud.aiplatform.v1beta1.JobService.ListCustomJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListCustomJobsRequest = src.ListCustomJobsRequest

// Response message for
// [JobService.ListCustomJobs][google.cloud.aiplatform.v1beta1.JobService.ListCustomJobs]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListCustomJobsResponse = src.ListCustomJobsResponse

// Request message for
// [DatasetService.ListDataItems][google.cloud.aiplatform.v1beta1.DatasetService.ListDataItems].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDataItemsRequest = src.ListDataItemsRequest

// Response message for
// [DatasetService.ListDataItems][google.cloud.aiplatform.v1beta1.DatasetService.ListDataItems].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDataItemsResponse = src.ListDataItemsResponse

// Request message for
// [JobService.ListDataLabelingJobs][google.cloud.aiplatform.v1beta1.JobService.ListDataLabelingJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDataLabelingJobsRequest = src.ListDataLabelingJobsRequest

// Response message for
// [JobService.ListDataLabelingJobs][google.cloud.aiplatform.v1beta1.JobService.ListDataLabelingJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDataLabelingJobsResponse = src.ListDataLabelingJobsResponse

// Request message for
// [DatasetService.ListDatasets][google.cloud.aiplatform.v1beta1.DatasetService.ListDatasets].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDatasetsRequest = src.ListDatasetsRequest

// Response message for
// [DatasetService.ListDatasets][google.cloud.aiplatform.v1beta1.DatasetService.ListDatasets].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDatasetsResponse = src.ListDatasetsResponse

// Request message for ListDeploymentResourcePools method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDeploymentResourcePoolsRequest = src.ListDeploymentResourcePoolsRequest

// Response message for ListDeploymentResourcePools method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListDeploymentResourcePoolsResponse = src.ListDeploymentResourcePoolsResponse

// Request message for
// [EndpointService.ListEndpoints][google.cloud.aiplatform.v1beta1.EndpointService.ListEndpoints].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListEndpointsRequest = src.ListEndpointsRequest

// Response message for
// [EndpointService.ListEndpoints][google.cloud.aiplatform.v1beta1.EndpointService.ListEndpoints].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListEndpointsResponse = src.ListEndpointsResponse

// Request message for
// [FeaturestoreService.ListEntityTypes][google.cloud.aiplatform.v1beta1.FeaturestoreService.ListEntityTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListEntityTypesRequest = src.ListEntityTypesRequest

// Response message for
// [FeaturestoreService.ListEntityTypes][google.cloud.aiplatform.v1beta1.FeaturestoreService.ListEntityTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListEntityTypesResponse = src.ListEntityTypesResponse

// Request message for
// [MetadataService.ListExecutions][google.cloud.aiplatform.v1beta1.MetadataService.ListExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListExecutionsRequest = src.ListExecutionsRequest

// Response message for
// [MetadataService.ListExecutions][google.cloud.aiplatform.v1beta1.MetadataService.ListExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListExecutionsResponse = src.ListExecutionsResponse

// Request message for
// [FeaturestoreService.ListFeatures][google.cloud.aiplatform.v1beta1.FeaturestoreService.ListFeatures].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListFeaturesRequest = src.ListFeaturesRequest

// Response message for
// [FeaturestoreService.ListFeatures][google.cloud.aiplatform.v1beta1.FeaturestoreService.ListFeatures].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListFeaturesResponse = src.ListFeaturesResponse

// Request message for
// [FeaturestoreService.ListFeaturestores][google.cloud.aiplatform.v1beta1.FeaturestoreService.ListFeaturestores].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListFeaturestoresRequest = src.ListFeaturestoresRequest

// Response message for
// [FeaturestoreService.ListFeaturestores][google.cloud.aiplatform.v1beta1.FeaturestoreService.ListFeaturestores].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListFeaturestoresResponse = src.ListFeaturestoresResponse

// Request message for
// [JobService.ListHyperparameterTuningJobs][google.cloud.aiplatform.v1beta1.JobService.ListHyperparameterTuningJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListHyperparameterTuningJobsRequest = src.ListHyperparameterTuningJobsRequest

// Response message for
// [JobService.ListHyperparameterTuningJobs][google.cloud.aiplatform.v1beta1.JobService.ListHyperparameterTuningJobs]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListHyperparameterTuningJobsResponse = src.ListHyperparameterTuningJobsResponse

// Request message for
// [IndexEndpointService.ListIndexEndpoints][google.cloud.aiplatform.v1beta1.IndexEndpointService.ListIndexEndpoints].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListIndexEndpointsRequest = src.ListIndexEndpointsRequest

// Response message for
// [IndexEndpointService.ListIndexEndpoints][google.cloud.aiplatform.v1beta1.IndexEndpointService.ListIndexEndpoints].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListIndexEndpointsResponse = src.ListIndexEndpointsResponse

// Request message for
// [IndexService.ListIndexes][google.cloud.aiplatform.v1beta1.IndexService.ListIndexes].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListIndexesRequest = src.ListIndexesRequest

// Response message for
// [IndexService.ListIndexes][google.cloud.aiplatform.v1beta1.IndexService.ListIndexes].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListIndexesResponse = src.ListIndexesResponse

// Request message for
// [MetadataService.ListMetadataSchemas][google.cloud.aiplatform.v1beta1.MetadataService.ListMetadataSchemas].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListMetadataSchemasRequest = src.ListMetadataSchemasRequest

// Response message for
// [MetadataService.ListMetadataSchemas][google.cloud.aiplatform.v1beta1.MetadataService.ListMetadataSchemas].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListMetadataSchemasResponse = src.ListMetadataSchemasResponse

// Request message for
// [MetadataService.ListMetadataStores][google.cloud.aiplatform.v1beta1.MetadataService.ListMetadataStores].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListMetadataStoresRequest = src.ListMetadataStoresRequest

// Response message for
// [MetadataService.ListMetadataStores][google.cloud.aiplatform.v1beta1.MetadataService.ListMetadataStores].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListMetadataStoresResponse = src.ListMetadataStoresResponse

// Request message for
// [JobService.ListModelDeploymentMonitoringJobs][google.cloud.aiplatform.v1beta1.JobService.ListModelDeploymentMonitoringJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelDeploymentMonitoringJobsRequest = src.ListModelDeploymentMonitoringJobsRequest

// Response message for
// [JobService.ListModelDeploymentMonitoringJobs][google.cloud.aiplatform.v1beta1.JobService.ListModelDeploymentMonitoringJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelDeploymentMonitoringJobsResponse = src.ListModelDeploymentMonitoringJobsResponse

// Request message for
// [ModelService.ListModelEvaluationSlices][google.cloud.aiplatform.v1beta1.ModelService.ListModelEvaluationSlices].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelEvaluationSlicesRequest = src.ListModelEvaluationSlicesRequest

// Response message for
// [ModelService.ListModelEvaluationSlices][google.cloud.aiplatform.v1beta1.ModelService.ListModelEvaluationSlices].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelEvaluationSlicesResponse = src.ListModelEvaluationSlicesResponse

// Request message for
// [ModelService.ListModelEvaluations][google.cloud.aiplatform.v1beta1.ModelService.ListModelEvaluations].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelEvaluationsRequest = src.ListModelEvaluationsRequest

// Response message for
// [ModelService.ListModelEvaluations][google.cloud.aiplatform.v1beta1.ModelService.ListModelEvaluations].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelEvaluationsResponse = src.ListModelEvaluationsResponse

// Request message for
// [ModelService.ListModelVersions][google.cloud.aiplatform.v1beta1.ModelService.ListModelVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelVersionsRequest = src.ListModelVersionsRequest

// Response message for
// [ModelService.ListModelVersions][google.cloud.aiplatform.v1beta1.ModelService.ListModelVersions]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelVersionsResponse = src.ListModelVersionsResponse

// Request message for
// [ModelService.ListModels][google.cloud.aiplatform.v1beta1.ModelService.ListModels].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelsRequest = src.ListModelsRequest

// Response message for
// [ModelService.ListModels][google.cloud.aiplatform.v1beta1.ModelService.ListModels]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListModelsResponse = src.ListModelsResponse

// Request message for
// [VizierService.ListOptimalTrials][google.cloud.aiplatform.v1beta1.VizierService.ListOptimalTrials].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListOptimalTrialsRequest = src.ListOptimalTrialsRequest

// Response message for
// [VizierService.ListOptimalTrials][google.cloud.aiplatform.v1beta1.VizierService.ListOptimalTrials].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListOptimalTrialsResponse = src.ListOptimalTrialsResponse

// Request message for
// [PipelineService.ListPipelineJobs][google.cloud.aiplatform.v1beta1.PipelineService.ListPipelineJobs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListPipelineJobsRequest = src.ListPipelineJobsRequest

// Response message for
// [PipelineService.ListPipelineJobs][google.cloud.aiplatform.v1beta1.PipelineService.ListPipelineJobs]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListPipelineJobsResponse = src.ListPipelineJobsResponse

// Request message for
// [DatasetService.ListSavedQueries][google.cloud.aiplatform.v1beta1.DatasetService.ListSavedQueries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListSavedQueriesRequest = src.ListSavedQueriesRequest

// Response message for
// [DatasetService.ListSavedQueries][google.cloud.aiplatform.v1beta1.DatasetService.ListSavedQueries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListSavedQueriesResponse = src.ListSavedQueriesResponse

// Request message for
// [SpecialistPoolService.ListSpecialistPools][google.cloud.aiplatform.v1beta1.SpecialistPoolService.ListSpecialistPools].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListSpecialistPoolsRequest = src.ListSpecialistPoolsRequest

// Response message for
// [SpecialistPoolService.ListSpecialistPools][google.cloud.aiplatform.v1beta1.SpecialistPoolService.ListSpecialistPools].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListSpecialistPoolsResponse = src.ListSpecialistPoolsResponse

// Request message for
// [VizierService.ListStudies][google.cloud.aiplatform.v1beta1.VizierService.ListStudies].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListStudiesRequest = src.ListStudiesRequest

// Response message for
// [VizierService.ListStudies][google.cloud.aiplatform.v1beta1.VizierService.ListStudies].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListStudiesResponse = src.ListStudiesResponse

// Request message for
// [TensorboardService.ListTensorboardExperiments][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboardExperiments].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardExperimentsRequest = src.ListTensorboardExperimentsRequest

// Response message for
// [TensorboardService.ListTensorboardExperiments][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboardExperiments].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardExperimentsResponse = src.ListTensorboardExperimentsResponse

// Request message for
// [TensorboardService.ListTensorboardRuns][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboardRuns].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardRunsRequest = src.ListTensorboardRunsRequest

// Response message for
// [TensorboardService.ListTensorboardRuns][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboardRuns].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardRunsResponse = src.ListTensorboardRunsResponse

// Request message for
// [TensorboardService.ListTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardTimeSeriesRequest = src.ListTensorboardTimeSeriesRequest

// Response message for
// [TensorboardService.ListTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardTimeSeriesResponse = src.ListTensorboardTimeSeriesResponse

// Request message for
// [TensorboardService.ListTensorboards][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboards].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardsRequest = src.ListTensorboardsRequest

// Response message for
// [TensorboardService.ListTensorboards][google.cloud.aiplatform.v1beta1.TensorboardService.ListTensorboards].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTensorboardsResponse = src.ListTensorboardsResponse

// Request message for
// [PipelineService.ListTrainingPipelines][google.cloud.aiplatform.v1beta1.PipelineService.ListTrainingPipelines].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTrainingPipelinesRequest = src.ListTrainingPipelinesRequest

// Response message for
// [PipelineService.ListTrainingPipelines][google.cloud.aiplatform.v1beta1.PipelineService.ListTrainingPipelines]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTrainingPipelinesResponse = src.ListTrainingPipelinesResponse

// Request message for
// [VizierService.ListTrials][google.cloud.aiplatform.v1beta1.VizierService.ListTrials].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTrialsRequest = src.ListTrialsRequest

// Response message for
// [VizierService.ListTrials][google.cloud.aiplatform.v1beta1.VizierService.ListTrials].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ListTrialsResponse = src.ListTrialsResponse

// Request message for
// [VizierService.LookupStudy][google.cloud.aiplatform.v1beta1.VizierService.LookupStudy].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type LookupStudyRequest = src.LookupStudyRequest

// Specification of a single machine.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MachineSpec = src.MachineSpec

// Manual batch tuning parameters.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ManualBatchTuningParameters = src.ManualBatchTuningParameters

// A message representing a Measurement of a Trial. A Measurement contains the
// Metrics got by executing a Trial using suggested hyperparameter values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Measurement = src.Measurement

// A message representing a metric in the measurement.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Measurement_Metric = src.Measurement_Metric

// Request message for
// [ModelService.MergeVersionAliases][google.cloud.aiplatform.v1beta1.ModelService.MergeVersionAliases].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MergeVersionAliasesRequest = src.MergeVersionAliasesRequest

// Instance of a general MetadataSchema.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MetadataSchema = src.MetadataSchema

// Describes the type of the MetadataSchema.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MetadataSchema_MetadataSchemaType = src.MetadataSchema_MetadataSchemaType

// MetadataServiceClient is the client API for MetadataService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MetadataServiceClient = src.MetadataServiceClient

// MetadataServiceServer is the server API for MetadataService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MetadataServiceServer = src.MetadataServiceServer

// Instance of a metadata store. Contains a set of metadata that can be
// queried.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MetadataStore = src.MetadataStore

// Represents state information for a MetadataStore.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MetadataStore_MetadataStoreState = src.MetadataStore_MetadataStoreState

// Represents one resource that exists in automl.googleapis.com,
// datalabeling.googleapis.com or ml.googleapis.com.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigratableResource = src.MigratableResource

// Represents one Dataset in automl.googleapis.com.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigratableResource_AutomlDataset = src.MigratableResource_AutomlDataset
type MigratableResource_AutomlDataset_ = src.MigratableResource_AutomlDataset_

// Represents one Model in automl.googleapis.com.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigratableResource_AutomlModel = src.MigratableResource_AutomlModel
type MigratableResource_AutomlModel_ = src.MigratableResource_AutomlModel_

// Represents one Dataset in datalabeling.googleapis.com.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigratableResource_DataLabelingDataset = src.MigratableResource_DataLabelingDataset
type MigratableResource_DataLabelingDataset_ = src.MigratableResource_DataLabelingDataset_

// Represents one AnnotatedDataset in datalabeling.googleapis.com.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigratableResource_DataLabelingDataset_DataLabelingAnnotatedDataset = src.MigratableResource_DataLabelingDataset_DataLabelingAnnotatedDataset

// Represents one model Version in ml.googleapis.com.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigratableResource_MlEngineModelVersion = src.MigratableResource_MlEngineModelVersion
type MigratableResource_MlEngineModelVersion_ = src.MigratableResource_MlEngineModelVersion_

// Config of migrating one resource from automl.googleapis.com,
// datalabeling.googleapis.com and ml.googleapis.com to Vertex AI.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceRequest = src.MigrateResourceRequest

// Config for migrating Dataset in automl.googleapis.com to Vertex AI's
// Dataset.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceRequest_MigrateAutomlDatasetConfig = src.MigrateResourceRequest_MigrateAutomlDatasetConfig
type MigrateResourceRequest_MigrateAutomlDatasetConfig_ = src.MigrateResourceRequest_MigrateAutomlDatasetConfig_

// Config for migrating Model in automl.googleapis.com to Vertex AI's Model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceRequest_MigrateAutomlModelConfig = src.MigrateResourceRequest_MigrateAutomlModelConfig
type MigrateResourceRequest_MigrateAutomlModelConfig_ = src.MigrateResourceRequest_MigrateAutomlModelConfig_

// Config for migrating Dataset in datalabeling.googleapis.com to Vertex AI's
// Dataset.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceRequest_MigrateDataLabelingDatasetConfig = src.MigrateResourceRequest_MigrateDataLabelingDatasetConfig
type MigrateResourceRequest_MigrateDataLabelingDatasetConfig_ = src.MigrateResourceRequest_MigrateDataLabelingDatasetConfig_

// Config for migrating AnnotatedDataset in datalabeling.googleapis.com to
// Vertex AI's SavedQuery.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceRequest_MigrateDataLabelingDatasetConfig_MigrateDataLabelingAnnotatedDatasetConfig = src.MigrateResourceRequest_MigrateDataLabelingDatasetConfig_MigrateDataLabelingAnnotatedDatasetConfig

// Config for migrating version in ml.googleapis.com to Vertex AI's Model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceRequest_MigrateMlEngineModelVersionConfig = src.MigrateResourceRequest_MigrateMlEngineModelVersionConfig
type MigrateResourceRequest_MigrateMlEngineModelVersionConfig_ = src.MigrateResourceRequest_MigrateMlEngineModelVersionConfig_

// Describes a successfully migrated resource.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrateResourceResponse = src.MigrateResourceResponse
type MigrateResourceResponse_Dataset = src.MigrateResourceResponse_Dataset
type MigrateResourceResponse_Model = src.MigrateResourceResponse_Model

// MigrationServiceClient is the client API for MigrationService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrationServiceClient = src.MigrationServiceClient

// MigrationServiceServer is the server API for MigrationService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MigrationServiceServer = src.MigrationServiceServer

// A trained machine learning Model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Model = src.Model

// Specification of a container for serving predictions. Some fields in this
// message correspond to fields in the [Kubernetes Container v1 core
// specification](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.23/#container-v1-core).
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelContainerSpec = src.ModelContainerSpec

// ModelDeploymentMonitoringBigQueryTable specifies the BigQuery table name as
// well as some information of the logs stored in this table.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringBigQueryTable = src.ModelDeploymentMonitoringBigQueryTable

// Indicates where does the log come from.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringBigQueryTable_LogSource = src.ModelDeploymentMonitoringBigQueryTable_LogSource

// Indicates what type of traffic does the log belong to.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringBigQueryTable_LogType = src.ModelDeploymentMonitoringBigQueryTable_LogType

// Represents a job that runs periodically to monitor the deployed models in
// an endpoint. It will analyze the logged training & prediction data to detect
// any abnormal behaviors.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringJob = src.ModelDeploymentMonitoringJob

// All metadata of most recent monitoring pipelines.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringJob_LatestMonitoringPipelineMetadata = src.ModelDeploymentMonitoringJob_LatestMonitoringPipelineMetadata

// The state to Specify the monitoring pipeline.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringJob_MonitoringScheduleState = src.ModelDeploymentMonitoringJob_MonitoringScheduleState

// ModelDeploymentMonitoringObjectiveConfig contains the pair of
// deployed_model_id to ModelMonitoringObjectiveConfig.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringObjectiveConfig = src.ModelDeploymentMonitoringObjectiveConfig

// The Model Monitoring Objective types.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringObjectiveType = src.ModelDeploymentMonitoringObjectiveType

// The config for scheduling monitoring job.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelDeploymentMonitoringScheduleConfig = src.ModelDeploymentMonitoringScheduleConfig

// A collection of metrics calculated by comparing Model's predictions on all
// of the test data against annotations from the test data.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelEvaluation = src.ModelEvaluation

// A collection of metrics calculated by comparing Model's predictions on a
// slice of the test data against ground truth annotations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelEvaluationSlice = src.ModelEvaluationSlice

// Definition of a slice.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelEvaluationSlice_Slice = src.ModelEvaluationSlice_Slice
type ModelEvaluation_ModelEvaluationExplanationSpec = src.ModelEvaluation_ModelEvaluationExplanationSpec

// Aggregated explanation metrics for a Model over a set of instances.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelExplanation = src.ModelExplanation
type ModelMonitoringAlertConfig = src.ModelMonitoringAlertConfig

// The config for email alert.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringAlertConfig_EmailAlertConfig = src.ModelMonitoringAlertConfig_EmailAlertConfig
type ModelMonitoringAlertConfig_EmailAlertConfig_ = src.ModelMonitoringAlertConfig_EmailAlertConfig_

// The model monitoring configuration used for Batch Prediction Job.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringConfig = src.ModelMonitoringConfig

// The objective configuration for model monitoring, including the information
// needed to detect anomalies for one particular model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig = src.ModelMonitoringObjectiveConfig

// The config for integrating with Vertex Explainable AI. Only applicable if
// the Model has explanation_spec populated.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig_ExplanationConfig = src.ModelMonitoringObjectiveConfig_ExplanationConfig

// Output from
// [BatchPredictionJob][google.cloud.aiplatform.v1beta1.BatchPredictionJob] for
// Model Monitoring baseline dataset, which can be used to generate baseline
// attribution scores.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline
type ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_Bigquery = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_Bigquery
type ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_Gcs = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_Gcs

// The storage format of the predictions generated BatchPrediction job.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PredictionFormat = src.ModelMonitoringObjectiveConfig_ExplanationConfig_ExplanationBaseline_PredictionFormat

// The config for Prediction data drift detection.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig_PredictionDriftDetectionConfig = src.ModelMonitoringObjectiveConfig_PredictionDriftDetectionConfig

// Training Dataset information.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig_TrainingDataset = src.ModelMonitoringObjectiveConfig_TrainingDataset
type ModelMonitoringObjectiveConfig_TrainingDataset_BigquerySource = src.ModelMonitoringObjectiveConfig_TrainingDataset_BigquerySource
type ModelMonitoringObjectiveConfig_TrainingDataset_Dataset = src.ModelMonitoringObjectiveConfig_TrainingDataset_Dataset
type ModelMonitoringObjectiveConfig_TrainingDataset_GcsSource = src.ModelMonitoringObjectiveConfig_TrainingDataset_GcsSource

// The config for Training & Prediction data skew detection. It specifies the
// training dataset sources and the skew detection parameters.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringObjectiveConfig_TrainingPredictionSkewDetectionConfig = src.ModelMonitoringObjectiveConfig_TrainingPredictionSkewDetectionConfig

// Statistics and anomalies generated by Model Monitoring.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringStatsAnomalies = src.ModelMonitoringStatsAnomalies

// Historical Stats (and Anomalies) for a specific Feature.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelMonitoringStatsAnomalies_FeatureHistoricStatsAnomalies = src.ModelMonitoringStatsAnomalies_FeatureHistoricStatsAnomalies

// ModelServiceClient is the client API for ModelService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelServiceClient = src.ModelServiceClient

// ModelServiceServer is the server API for ModelService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelServiceServer = src.ModelServiceServer

// Detail description of the source information of the model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelSourceInfo = src.ModelSourceInfo

// Source of the model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ModelSourceInfo_ModelSourceType = src.ModelSourceInfo_ModelSourceType

// Identifies a type of Model's prediction resources.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Model_DeploymentResourcesType = src.Model_DeploymentResourcesType

// Represents export format supported by the Model. All formats export to
// Google Cloud Storage.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Model_ExportFormat = src.Model_ExportFormat

// The Model content that can be exported.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Model_ExportFormat_ExportableContent = src.Model_ExportFormat_ExportableContent

// Runtime operation information for
// [IndexEndpointService.MutateDeployedIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.MutateDeployedIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MutateDeployedIndexOperationMetadata = src.MutateDeployedIndexOperationMetadata

// Request message for
// [IndexEndpointService.MutateDeployedIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.MutateDeployedIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MutateDeployedIndexRequest = src.MutateDeployedIndexRequest

// Response message for
// [IndexEndpointService.MutateDeployedIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.MutateDeployedIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type MutateDeployedIndexResponse = src.MutateDeployedIndexResponse

// Runtime operation metadata with regard to Matching Engine Index.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type NearestNeighborSearchOperationMetadata = src.NearestNeighborSearchOperationMetadata
type NearestNeighborSearchOperationMetadata_ContentValidationStats = src.NearestNeighborSearchOperationMetadata_ContentValidationStats
type NearestNeighborSearchOperationMetadata_RecordError = src.NearestNeighborSearchOperationMetadata_RecordError
type NearestNeighborSearchOperationMetadata_RecordError_RecordErrorType = src.NearestNeighborSearchOperationMetadata_RecordError_RecordErrorType

// Neighbors for example-based explanations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Neighbor = src.Neighbor

// Represents a mount configuration for Network File System (NFS) to mount.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type NfsMount = src.NfsMount

// Request message for
// [JobService.PauseModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.PauseModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PauseModelDeploymentMonitoringJobRequest = src.PauseModelDeploymentMonitoringJobRequest

// Represents the failure policy of a pipeline. Currently, the default of a
// pipeline is that the pipeline will continue to run until no more tasks can
// be executed, also known as PIPELINE_FAILURE_POLICY_FAIL_SLOW. However, if a
// pipeline is set to PIPELINE_FAILURE_POLICY_FAIL_FAST, it will stop
// scheduling any new tasks when a task has failed. Any scheduled tasks will
// continue to completion.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineFailurePolicy = src.PipelineFailurePolicy

// An instance of a machine learning PipelineJob.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineJob = src.PipelineJob

// The runtime detail of PipelineJob.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineJobDetail = src.PipelineJobDetail

// The runtime config of a PipelineJob.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineJob_RuntimeConfig = src.PipelineJob_RuntimeConfig

// The type of an input artifact.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineJob_RuntimeConfig_InputArtifact = src.PipelineJob_RuntimeConfig_InputArtifact
type PipelineJob_RuntimeConfig_InputArtifact_ArtifactId = src.PipelineJob_RuntimeConfig_InputArtifact_ArtifactId

// PipelineServiceClient is the client API for PipelineService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineServiceClient = src.PipelineServiceClient

// PipelineServiceServer is the server API for PipelineService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineServiceServer = src.PipelineServiceServer

// Describes the state of a pipeline.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineState = src.PipelineState

// The runtime detail of a task execution.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskDetail = src.PipelineTaskDetail

// A list of artifact metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskDetail_ArtifactList = src.PipelineTaskDetail_ArtifactList

// A single record of the task status.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskDetail_PipelineTaskStatus = src.PipelineTaskDetail_PipelineTaskStatus

// Specifies state of TaskExecution
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskDetail_State = src.PipelineTaskDetail_State

// The runtime detail of a pipeline executor.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskExecutorDetail = src.PipelineTaskExecutorDetail

// The detail of a container execution. It contains the job names of the
// lifecycle of a container execution.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskExecutorDetail_ContainerDetail = src.PipelineTaskExecutorDetail_ContainerDetail
type PipelineTaskExecutorDetail_ContainerDetail_ = src.PipelineTaskExecutorDetail_ContainerDetail_

// The detailed info for a custom job executor. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTaskExecutorDetail_CustomJobDetail = src.PipelineTaskExecutorDetail_CustomJobDetail
type PipelineTaskExecutorDetail_CustomJobDetail_ = src.PipelineTaskExecutorDetail_CustomJobDetail_

// Pipeline template metadata if
// [PipelineJob.template_uri][google.cloud.aiplatform.v1beta1.PipelineJob.template_uri]
// is from supported template registry. Currently, the only supported registry
// is Artifact Registry.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PipelineTemplateMetadata = src.PipelineTemplateMetadata

// Represents a network port in a container.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Port = src.Port

// Assigns input data to training, validation, and test sets based on the
// value of a provided key. Supported only for tabular Datasets.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredefinedSplit = src.PredefinedSplit

// Request message for
// [PredictionService.Predict][google.cloud.aiplatform.v1beta1.PredictionService.Predict].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredictRequest = src.PredictRequest

// Configuration for logging request-response to a BigQuery table.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredictRequestResponseLoggingConfig = src.PredictRequestResponseLoggingConfig

// Response message for
// [PredictionService.Predict][google.cloud.aiplatform.v1beta1.PredictionService.Predict].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredictResponse = src.PredictResponse

// Contains the schemata used in Model's predictions and explanations via
// [PredictionService.Predict][google.cloud.aiplatform.v1beta1.PredictionService.Predict],
// [PredictionService.Explain][google.cloud.aiplatform.v1beta1.PredictionService.Explain]
// and
// [BatchPredictionJob][google.cloud.aiplatform.v1beta1.BatchPredictionJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredictSchemata = src.PredictSchemata

// PredictionServiceClient is the client API for PredictionService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredictionServiceClient = src.PredictionServiceClient

// PredictionServiceServer is the server API for PredictionService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PredictionServiceServer = src.PredictionServiceServer

// Preset configuration for example-based explanations
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Presets = src.Presets

// Preset option controlling parameters for different modalities
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Presets_Modality = src.Presets_Modality

// Preset option controlling parameters for query speed-precision trade-off
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Presets_Query = src.Presets_Query

// PrivateEndpoints proto is used to provide paths for users to send requests
// privately. To send request via private service access, use predict_http_uri,
// explain_http_uri or health_http_uri. To send request via private service
// connect, use service_attachment.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PrivateEndpoints = src.PrivateEndpoints

// Details of operations that perform
// [MetadataService.PurgeArtifacts][google.cloud.aiplatform.v1beta1.MetadataService.PurgeArtifacts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeArtifactsMetadata = src.PurgeArtifactsMetadata

// Request message for
// [MetadataService.PurgeArtifacts][google.cloud.aiplatform.v1beta1.MetadataService.PurgeArtifacts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeArtifactsRequest = src.PurgeArtifactsRequest

// Response message for
// [MetadataService.PurgeArtifacts][google.cloud.aiplatform.v1beta1.MetadataService.PurgeArtifacts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeArtifactsResponse = src.PurgeArtifactsResponse

// Details of operations that perform
// [MetadataService.PurgeContexts][google.cloud.aiplatform.v1beta1.MetadataService.PurgeContexts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeContextsMetadata = src.PurgeContextsMetadata

// Request message for
// [MetadataService.PurgeContexts][google.cloud.aiplatform.v1beta1.MetadataService.PurgeContexts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeContextsRequest = src.PurgeContextsRequest

// Response message for
// [MetadataService.PurgeContexts][google.cloud.aiplatform.v1beta1.MetadataService.PurgeContexts].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeContextsResponse = src.PurgeContextsResponse

// Details of operations that perform
// [MetadataService.PurgeExecutions][google.cloud.aiplatform.v1beta1.MetadataService.PurgeExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeExecutionsMetadata = src.PurgeExecutionsMetadata

// Request message for
// [MetadataService.PurgeExecutions][google.cloud.aiplatform.v1beta1.MetadataService.PurgeExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeExecutionsRequest = src.PurgeExecutionsRequest

// Response message for
// [MetadataService.PurgeExecutions][google.cloud.aiplatform.v1beta1.MetadataService.PurgeExecutions].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PurgeExecutionsResponse = src.PurgeExecutionsResponse

// The spec of a Python packaged code.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type PythonPackageSpec = src.PythonPackageSpec

// Request message for
// [MetadataService.QueryArtifactLineageSubgraph][google.cloud.aiplatform.v1beta1.MetadataService.QueryArtifactLineageSubgraph].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type QueryArtifactLineageSubgraphRequest = src.QueryArtifactLineageSubgraphRequest

// Request message for
// [MetadataService.QueryContextLineageSubgraph][google.cloud.aiplatform.v1beta1.MetadataService.QueryContextLineageSubgraph].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type QueryContextLineageSubgraphRequest = src.QueryContextLineageSubgraphRequest

// Request message for QueryDeployedModels method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type QueryDeployedModelsRequest = src.QueryDeployedModelsRequest

// Response message for QueryDeployedModels method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type QueryDeployedModelsResponse = src.QueryDeployedModelsResponse

// Request message for
// [MetadataService.QueryExecutionInputsAndOutputs][google.cloud.aiplatform.v1beta1.MetadataService.QueryExecutionInputsAndOutputs].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type QueryExecutionInputsAndOutputsRequest = src.QueryExecutionInputsAndOutputsRequest

// Request message for
// [PredictionService.RawPredict][google.cloud.aiplatform.v1beta1.PredictionService.RawPredict].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type RawPredictRequest = src.RawPredictRequest

// Request message for
// [FeaturestoreOnlineServingService.ReadFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreOnlineServingService.ReadFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadFeatureValuesRequest = src.ReadFeatureValuesRequest

// Response message for
// [FeaturestoreOnlineServingService.ReadFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreOnlineServingService.ReadFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadFeatureValuesResponse = src.ReadFeatureValuesResponse

// Entity view with Feature values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadFeatureValuesResponse_EntityView = src.ReadFeatureValuesResponse_EntityView

// Container to hold value(s), successive in time, for one Feature from the
// request.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadFeatureValuesResponse_EntityView_Data = src.ReadFeatureValuesResponse_EntityView_Data
type ReadFeatureValuesResponse_EntityView_Data_Value = src.ReadFeatureValuesResponse_EntityView_Data_Value
type ReadFeatureValuesResponse_EntityView_Data_Values = src.ReadFeatureValuesResponse_EntityView_Data_Values

// Metadata for requested Features.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadFeatureValuesResponse_FeatureDescriptor = src.ReadFeatureValuesResponse_FeatureDescriptor

// Response header with metadata for the requested
// [ReadFeatureValuesRequest.entity_type][google.cloud.aiplatform.v1beta1.ReadFeatureValuesRequest.entity_type]
// and Features.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadFeatureValuesResponse_Header = src.ReadFeatureValuesResponse_Header

// Request message for
// [TensorboardService.ReadTensorboardBlobData][google.cloud.aiplatform.v1beta1.TensorboardService.ReadTensorboardBlobData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadTensorboardBlobDataRequest = src.ReadTensorboardBlobDataRequest

// Response message for
// [TensorboardService.ReadTensorboardBlobData][google.cloud.aiplatform.v1beta1.TensorboardService.ReadTensorboardBlobData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadTensorboardBlobDataResponse = src.ReadTensorboardBlobDataResponse

// Request message for
// [TensorboardService.ReadTensorboardTimeSeriesData][google.cloud.aiplatform.v1beta1.TensorboardService.ReadTensorboardTimeSeriesData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadTensorboardTimeSeriesDataRequest = src.ReadTensorboardTimeSeriesDataRequest

// Response message for
// [TensorboardService.ReadTensorboardTimeSeriesData][google.cloud.aiplatform.v1beta1.TensorboardService.ReadTensorboardTimeSeriesData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ReadTensorboardTimeSeriesDataResponse = src.ReadTensorboardTimeSeriesDataResponse

// Request message for [MetadataService.DeleteContextChildrenRequest][].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type RemoveContextChildrenRequest = src.RemoveContextChildrenRequest

// Response message for
// [MetadataService.RemoveContextChildren][google.cloud.aiplatform.v1beta1.MetadataService.RemoveContextChildren].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type RemoveContextChildrenResponse = src.RemoveContextChildrenResponse

// Request message for
// [IndexService.RemoveDatapoints][google.cloud.aiplatform.v1beta1.IndexService.RemoveDatapoints]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type RemoveDatapointsRequest = src.RemoveDatapointsRequest

// Response message for
// [IndexService.RemoveDatapoints][google.cloud.aiplatform.v1beta1.IndexService.RemoveDatapoints]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type RemoveDatapointsResponse = src.RemoveDatapointsResponse

// Statistics information about resource consumption.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ResourcesConsumed = src.ResourcesConsumed

// Request message for
// [JobService.ResumeModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.ResumeModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ResumeModelDeploymentMonitoringJobRequest = src.ResumeModelDeploymentMonitoringJobRequest

// Active learning data sampling config. For every active learning labeling
// iteration, it will select a batch of data based on the sampling strategy.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SampleConfig = src.SampleConfig
type SampleConfig_FollowingBatchSamplePercentage = src.SampleConfig_FollowingBatchSamplePercentage
type SampleConfig_InitialBatchSamplePercentage = src.SampleConfig_InitialBatchSamplePercentage

// Sample strategy decides which subset of DataItems should be selected for
// human labeling in every batch.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SampleConfig_SampleStrategy = src.SampleConfig_SampleStrategy

// An attribution method that approximates Shapley values for features that
// contribute to the label being predicted. A sampling strategy is used to
// approximate the value rather than considering all subsets of features.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SampledShapleyAttribution = src.SampledShapleyAttribution

// Sampling Strategy for logging, can be for both training and prediction
// dataset.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SamplingStrategy = src.SamplingStrategy

// Requests are randomly selected.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SamplingStrategy_RandomSampleConfig = src.SamplingStrategy_RandomSampleConfig

// A SavedQuery is a view of the dataset. It references a subset of
// annotations by problem type and filters.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SavedQuery = src.SavedQuery

// One point viewable on a scalar metric plot.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Scalar = src.Scalar

// All parameters related to queuing and scheduling of custom jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Scheduling = src.Scheduling

// Request message for
// [FeaturestoreService.SearchFeatures][google.cloud.aiplatform.v1beta1.FeaturestoreService.SearchFeatures].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchFeaturesRequest = src.SearchFeaturesRequest

// Response message for
// [FeaturestoreService.SearchFeatures][google.cloud.aiplatform.v1beta1.FeaturestoreService.SearchFeatures].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchFeaturesResponse = src.SearchFeaturesResponse

// Request message for
// [MigrationService.SearchMigratableResources][google.cloud.aiplatform.v1beta1.MigrationService.SearchMigratableResources].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchMigratableResourcesRequest = src.SearchMigratableResourcesRequest

// Response message for
// [MigrationService.SearchMigratableResources][google.cloud.aiplatform.v1beta1.MigrationService.SearchMigratableResources].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchMigratableResourcesResponse = src.SearchMigratableResourcesResponse

// Request message for
// [JobService.SearchModelDeploymentMonitoringStatsAnomalies][google.cloud.aiplatform.v1beta1.JobService.SearchModelDeploymentMonitoringStatsAnomalies].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchModelDeploymentMonitoringStatsAnomaliesRequest = src.SearchModelDeploymentMonitoringStatsAnomaliesRequest

// Stats requested for specific objective.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective = src.SearchModelDeploymentMonitoringStatsAnomaliesRequest_StatsAnomaliesObjective

// Response message for
// [JobService.SearchModelDeploymentMonitoringStatsAnomalies][google.cloud.aiplatform.v1beta1.JobService.SearchModelDeploymentMonitoringStatsAnomalies].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SearchModelDeploymentMonitoringStatsAnomaliesResponse = src.SearchModelDeploymentMonitoringStatsAnomaliesResponse

// Config for SmoothGrad approximation of gradients. When enabled, the
// gradients are approximated by averaging the gradients from noisy samples in
// the vicinity of the inputs. Adding noise can help improve the computed
// gradients. Refer to this paper for more details:
// https://arxiv.org/pdf/1706.03825.pdf
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SmoothGradConfig = src.SmoothGradConfig
type SmoothGradConfig_FeatureNoiseSigma = src.SmoothGradConfig_FeatureNoiseSigma
type SmoothGradConfig_NoiseSigma = src.SmoothGradConfig_NoiseSigma

// SpecialistPool represents customers' own workforce to work on their data
// labeling jobs. It includes a group of specialist managers and workers.
// Managers are responsible for managing the workers in this pool as well as
// customers' data labeling jobs associated with this pool. Customers create
// specialist pool as well as start data labeling jobs on Cloud, managers and
// workers handle the jobs using CrowdCompute console.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SpecialistPool = src.SpecialistPool

// SpecialistPoolServiceClient is the client API for SpecialistPoolService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SpecialistPoolServiceClient = src.SpecialistPoolServiceClient

// SpecialistPoolServiceServer is the server API for SpecialistPoolService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SpecialistPoolServiceServer = src.SpecialistPoolServiceServer

// Request message for
// [VizierService.StopTrial][google.cloud.aiplatform.v1beta1.VizierService.StopTrial].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StopTrialRequest = src.StopTrialRequest

// Assigns input data to the training, validation, and test sets so that the
// distribution of values found in the categorical column (as specified by the
// `key` field) is mirrored within each split. The fraction values determine
// the relative sizes of the splits. For example, if the specified column has
// three values, with 50% of the rows having value "A", 25% value "B", and 25%
// value "C", and the split fractions are specified as 80/10/10, then the
// training set will constitute 80% of the training data, with about 50% of the
// training set rows having the value "A" for the specified column, about 25%
// having the value "B", and about 25% having the value "C". Only the top 500
// occurring values are used; any values not in the top 500 values are randomly
// assigned to a split. If less than three rows contain a specific value, those
// rows are randomly assigned. Supported only for tabular Datasets.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StratifiedSplit = src.StratifiedSplit

// Request message for
// [FeaturestoreOnlineServingService.StreamingFeatureValuesRead][].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StreamingReadFeatureValuesRequest = src.StreamingReadFeatureValuesRequest

// A list of string values.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StringArray = src.StringArray

// A message representing a Study.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Study = src.Study

// Represents specification of a Study.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec = src.StudySpec

// The available search algorithms for the Study.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_Algorithm = src.StudySpec_Algorithm

// Configuration for ConvexAutomatedStoppingSpec. When there are enough
// completed trials (configured by min_measurement_count), for pending trials
// with enough measurements and steps, the policy first computes an
// overestimate of the objective value at max_num_steps according to the slope
// of the incomplete objective value curve. No prediction can be made if the
// curve is completely flat. If the overestimation is worse than the best
// objective value of the completed trials, this pending trial will be
// early-stopped, but a last measurement will be added to the pending trial
// with max_num_steps and predicted objective value from the autoregression
// model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ConvexAutomatedStoppingSpec = src.StudySpec_ConvexAutomatedStoppingSpec
type StudySpec_ConvexAutomatedStoppingSpec_ = src.StudySpec_ConvexAutomatedStoppingSpec_

// Configuration for ConvexStopPolicy. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ConvexStopConfig = src.StudySpec_ConvexStopConfig
type StudySpec_ConvexStopConfig_ = src.StudySpec_ConvexStopConfig_

// The decay curve automated stopping rule builds a Gaussian Process Regressor
// to predict the final objective value of a Trial based on the already
// completed Trials and the intermediate measurements of the current Trial.
// Early stopping is requested for the current Trial if there is very low
// probability to exceed the optimal value found so far.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_DecayCurveAutomatedStoppingSpec = src.StudySpec_DecayCurveAutomatedStoppingSpec
type StudySpec_DecayCurveStoppingSpec = src.StudySpec_DecayCurveStoppingSpec

// This indicates which measurement to use if/when the service automatically
// selects the final measurement from previously reported intermediate
// measurements. Choose this based on two considerations: A) Do you expect your
// measurements to monotonically improve? If so, choose LAST_MEASUREMENT. On
// the other hand, if you're in a situation where your system can "over-train"
// and you expect the performance to get better for a while but then start
// declining, choose BEST_MEASUREMENT. B) Are your measurements significantly
// noisy and/or irreproducible? If so, BEST_MEASUREMENT will tend to be
// over-optimistic, and it may be better to choose LAST_MEASUREMENT. If both or
// neither of (A) and (B) apply, it doesn't matter which selection type is
// chosen.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_MeasurementSelectionType = src.StudySpec_MeasurementSelectionType

// The median automated stopping rule stops a pending Trial if the Trial's
// best objective_value is strictly below the median 'performance' of all
// completed Trials reported up to the Trial's last measurement. Currently,
// 'performance' refers to the running average of the objective values reported
// by the Trial in each measurement.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_MedianAutomatedStoppingSpec = src.StudySpec_MedianAutomatedStoppingSpec
type StudySpec_MedianAutomatedStoppingSpec_ = src.StudySpec_MedianAutomatedStoppingSpec_

// Represents a metric to optimize.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_MetricSpec = src.StudySpec_MetricSpec

// The available types of optimization goals.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_MetricSpec_GoalType = src.StudySpec_MetricSpec_GoalType

// Describes the noise level of the repeated observations. "Noisy" means that
// the repeated observations with the same Trial parameters may lead to
// different metric evaluations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ObservationNoise = src.StudySpec_ObservationNoise

// Represents a single parameter to optimize.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec = src.StudySpec_ParameterSpec

// Value specification for a parameter in `CATEGORICAL` type.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_CategoricalValueSpec = src.StudySpec_ParameterSpec_CategoricalValueSpec
type StudySpec_ParameterSpec_CategoricalValueSpec_ = src.StudySpec_ParameterSpec_CategoricalValueSpec_

// Represents a parameter spec with condition from its parent parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_ConditionalParameterSpec = src.StudySpec_ParameterSpec_ConditionalParameterSpec

// Represents the spec to match categorical values from parent parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_ConditionalParameterSpec_CategoricalValueCondition = src.StudySpec_ParameterSpec_ConditionalParameterSpec_CategoricalValueCondition

// Represents the spec to match discrete values from parent parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_ConditionalParameterSpec_DiscreteValueCondition = src.StudySpec_ParameterSpec_ConditionalParameterSpec_DiscreteValueCondition

// Represents the spec to match integer values from parent parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_ConditionalParameterSpec_IntValueCondition = src.StudySpec_ParameterSpec_ConditionalParameterSpec_IntValueCondition
type StudySpec_ParameterSpec_ConditionalParameterSpec_ParentCategoricalValues = src.StudySpec_ParameterSpec_ConditionalParameterSpec_ParentCategoricalValues
type StudySpec_ParameterSpec_ConditionalParameterSpec_ParentDiscreteValues = src.StudySpec_ParameterSpec_ConditionalParameterSpec_ParentDiscreteValues
type StudySpec_ParameterSpec_ConditionalParameterSpec_ParentIntValues = src.StudySpec_ParameterSpec_ConditionalParameterSpec_ParentIntValues

// Value specification for a parameter in `DISCRETE` type.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_DiscreteValueSpec = src.StudySpec_ParameterSpec_DiscreteValueSpec
type StudySpec_ParameterSpec_DiscreteValueSpec_ = src.StudySpec_ParameterSpec_DiscreteValueSpec_

// Value specification for a parameter in `DOUBLE` type.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_DoubleValueSpec = src.StudySpec_ParameterSpec_DoubleValueSpec
type StudySpec_ParameterSpec_DoubleValueSpec_ = src.StudySpec_ParameterSpec_DoubleValueSpec_

// Value specification for a parameter in `INTEGER` type.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_IntegerValueSpec = src.StudySpec_ParameterSpec_IntegerValueSpec
type StudySpec_ParameterSpec_IntegerValueSpec_ = src.StudySpec_ParameterSpec_IntegerValueSpec_

// The type of scaling that should be applied to this parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_ParameterSpec_ScaleType = src.StudySpec_ParameterSpec_ScaleType

// This contains flag for manually disabling transfer learning for a study.
// The names of prior studies being used for transfer learning (if any) are
// also listed here.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type StudySpec_TransferLearningConfig = src.StudySpec_TransferLearningConfig

// Describes the Study state.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Study_State = src.Study_State

// Details of operations that perform Trials suggestion.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SuggestTrialsMetadata = src.SuggestTrialsMetadata

// Request message for
// [VizierService.SuggestTrials][google.cloud.aiplatform.v1beta1.VizierService.SuggestTrials].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SuggestTrialsRequest = src.SuggestTrialsRequest

// Response message for
// [VizierService.SuggestTrials][google.cloud.aiplatform.v1beta1.VizierService.SuggestTrials].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type SuggestTrialsResponse = src.SuggestTrialsResponse

// The storage details for TFRecord output content.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TFRecordDestination = src.TFRecordDestination

// Tensorboard is a physical database that stores users' training metrics. A
// default Tensorboard is provided in each region of a GCP project. If needed
// users can also create extra Tensorboards in their projects.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Tensorboard = src.Tensorboard

// One blob (e.g, image, graph) viewable on a blob metric plot.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardBlob = src.TensorboardBlob

// One point viewable on a blob metric plot, but mostly just a wrapper message
// to work around repeated fields can't be used directly within `oneof` fields.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardBlobSequence = src.TensorboardBlobSequence

// A TensorboardExperiment is a group of TensorboardRuns, that are typically
// the results of a training job run, in a Tensorboard.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardExperiment = src.TensorboardExperiment

// TensorboardRun maps to a specific execution of a training job with a given
// set of hyperparameter values, model definition, dataset, etc
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardRun = src.TensorboardRun

// TensorboardServiceClient is the client API for TensorboardService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardServiceClient = src.TensorboardServiceClient

// TensorboardServiceServer is the server API for TensorboardService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardServiceServer = src.TensorboardServiceServer
type TensorboardService_ReadTensorboardBlobDataClient = src.TensorboardService_ReadTensorboardBlobDataClient
type TensorboardService_ReadTensorboardBlobDataServer = src.TensorboardService_ReadTensorboardBlobDataServer

// One point viewable on a tensor metric plot.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardTensor = src.TensorboardTensor

// TensorboardTimeSeries maps to times series produced in training runs
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardTimeSeries = src.TensorboardTimeSeries

// Describes metadata for a TensorboardTimeSeries.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardTimeSeries_Metadata = src.TensorboardTimeSeries_Metadata

// An enum representing the value type of a TensorboardTimeSeries.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TensorboardTimeSeries_ValueType = src.TensorboardTimeSeries_ValueType

// The config for feature monitoring threshold.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type ThresholdConfig = src.ThresholdConfig
type ThresholdConfig_Value = src.ThresholdConfig_Value

// All the data stored in a TensorboardTimeSeries.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TimeSeriesData = src.TimeSeriesData

// A TensorboardTimeSeries data point.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TimeSeriesDataPoint = src.TimeSeriesDataPoint
type TimeSeriesDataPoint_Blobs = src.TimeSeriesDataPoint_Blobs
type TimeSeriesDataPoint_Scalar = src.TimeSeriesDataPoint_Scalar
type TimeSeriesDataPoint_Tensor = src.TimeSeriesDataPoint_Tensor

// Assigns input data to training, validation, and test sets based on a
// provided timestamps. The youngest data pieces are assigned to training set,
// next to validation set, and the oldest to the test set. Supported only for
// tabular Datasets.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TimestampSplit = src.TimestampSplit

// CMLE training config. For every active learning labeling iteration, system
// will train a machine learning model on CMLE. The trained model will be used
// by data sampling algorithm to select DataItems.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TrainingConfig = src.TrainingConfig

// The TrainingPipeline orchestrates tasks associated with training a Model.
// It always executes the training task, and optionally may also export data
// from Vertex AI's Dataset which becomes the training input,
// [upload][google.cloud.aiplatform.v1beta1.ModelService.UploadModel] the Model
// to Vertex AI, and evaluate the Model.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type TrainingPipeline = src.TrainingPipeline

// A message representing a Trial. A Trial contains a unique set of Parameters
// that has been or will be evaluated, along with the objective metrics got by
// running the Trial.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Trial = src.Trial

// A message representing a parameter to be tuned.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Trial_Parameter = src.Trial_Parameter

// Describes a Trial state.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Trial_State = src.Trial_State

// Runtime operation information for
// [IndexEndpointService.UndeployIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.UndeployIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UndeployIndexOperationMetadata = src.UndeployIndexOperationMetadata

// Request message for
// [IndexEndpointService.UndeployIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.UndeployIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UndeployIndexRequest = src.UndeployIndexRequest

// Response message for
// [IndexEndpointService.UndeployIndex][google.cloud.aiplatform.v1beta1.IndexEndpointService.UndeployIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UndeployIndexResponse = src.UndeployIndexResponse

// Runtime operation information for
// [EndpointService.UndeployModel][google.cloud.aiplatform.v1beta1.EndpointService.UndeployModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UndeployModelOperationMetadata = src.UndeployModelOperationMetadata

// Request message for
// [EndpointService.UndeployModel][google.cloud.aiplatform.v1beta1.EndpointService.UndeployModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UndeployModelRequest = src.UndeployModelRequest

// Response message for
// [EndpointService.UndeployModel][google.cloud.aiplatform.v1beta1.EndpointService.UndeployModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UndeployModelResponse = src.UndeployModelResponse

// UnimplementedDatasetServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedDatasetServiceServer = src.UnimplementedDatasetServiceServer

// UnimplementedDeploymentResourcePoolServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedDeploymentResourcePoolServiceServer = src.UnimplementedDeploymentResourcePoolServiceServer

// UnimplementedEndpointServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedEndpointServiceServer = src.UnimplementedEndpointServiceServer

// UnimplementedFeaturestoreOnlineServingServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedFeaturestoreOnlineServingServiceServer = src.UnimplementedFeaturestoreOnlineServingServiceServer

// UnimplementedFeaturestoreServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedFeaturestoreServiceServer = src.UnimplementedFeaturestoreServiceServer

// UnimplementedIndexEndpointServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedIndexEndpointServiceServer = src.UnimplementedIndexEndpointServiceServer

// UnimplementedIndexServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedIndexServiceServer = src.UnimplementedIndexServiceServer

// UnimplementedJobServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedJobServiceServer = src.UnimplementedJobServiceServer

// UnimplementedMetadataServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedMetadataServiceServer = src.UnimplementedMetadataServiceServer

// UnimplementedMigrationServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedMigrationServiceServer = src.UnimplementedMigrationServiceServer

// UnimplementedModelServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedModelServiceServer = src.UnimplementedModelServiceServer

// UnimplementedPipelineServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedPipelineServiceServer = src.UnimplementedPipelineServiceServer

// UnimplementedPredictionServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedPredictionServiceServer = src.UnimplementedPredictionServiceServer

// UnimplementedSpecialistPoolServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedSpecialistPoolServiceServer = src.UnimplementedSpecialistPoolServiceServer

// UnimplementedTensorboardServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedTensorboardServiceServer = src.UnimplementedTensorboardServiceServer

// UnimplementedVizierServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnimplementedVizierServiceServer = src.UnimplementedVizierServiceServer

// Contains model information necessary to perform batch prediction without
// requiring a full model import.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UnmanagedContainerModel = src.UnmanagedContainerModel

// Request message for
// [MetadataService.UpdateArtifact][google.cloud.aiplatform.v1beta1.MetadataService.UpdateArtifact].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateArtifactRequest = src.UpdateArtifactRequest

// Request message for
// [MetadataService.UpdateContext][google.cloud.aiplatform.v1beta1.MetadataService.UpdateContext].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateContextRequest = src.UpdateContextRequest

// Request message for
// [DatasetService.UpdateDataset][google.cloud.aiplatform.v1beta1.DatasetService.UpdateDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateDatasetRequest = src.UpdateDatasetRequest

// Runtime operation information for UpdateDeploymentResourcePool method.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateDeploymentResourcePoolOperationMetadata = src.UpdateDeploymentResourcePoolOperationMetadata

// Request message for
// [EndpointService.UpdateEndpoint][google.cloud.aiplatform.v1beta1.EndpointService.UpdateEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateEndpointRequest = src.UpdateEndpointRequest

// Request message for
// [FeaturestoreService.UpdateEntityType][google.cloud.aiplatform.v1beta1.FeaturestoreService.UpdateEntityType].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateEntityTypeRequest = src.UpdateEntityTypeRequest

// Request message for
// [MetadataService.UpdateExecution][google.cloud.aiplatform.v1beta1.MetadataService.UpdateExecution].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateExecutionRequest = src.UpdateExecutionRequest

// Runtime operation information for
// [ModelService.UpdateExplanationDataset][google.cloud.aiplatform.v1beta1.ModelService.UpdateExplanationDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateExplanationDatasetOperationMetadata = src.UpdateExplanationDatasetOperationMetadata

// Request message for
// [ModelService.UpdateExplanationDataset][google.cloud.aiplatform.v1beta1.ModelService.UpdateExplanationDataset].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateExplanationDatasetRequest = src.UpdateExplanationDatasetRequest

// Response message of
// [ModelService.UpdateExplanationDataset][google.cloud.aiplatform.v1beta1.ModelService.UpdateExplanationDataset]
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateExplanationDatasetResponse = src.UpdateExplanationDatasetResponse

// Request message for
// [FeaturestoreService.UpdateFeature][google.cloud.aiplatform.v1beta1.FeaturestoreService.UpdateFeature].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateFeatureRequest = src.UpdateFeatureRequest

// Details of operations that perform update Featurestore.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateFeaturestoreOperationMetadata = src.UpdateFeaturestoreOperationMetadata

// Request message for
// [FeaturestoreService.UpdateFeaturestore][google.cloud.aiplatform.v1beta1.FeaturestoreService.UpdateFeaturestore].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateFeaturestoreRequest = src.UpdateFeaturestoreRequest

// Request message for
// [IndexEndpointService.UpdateIndexEndpoint][google.cloud.aiplatform.v1beta1.IndexEndpointService.UpdateIndexEndpoint].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateIndexEndpointRequest = src.UpdateIndexEndpointRequest

// Runtime operation information for
// [IndexService.UpdateIndex][google.cloud.aiplatform.v1beta1.IndexService.UpdateIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateIndexOperationMetadata = src.UpdateIndexOperationMetadata

// Request message for
// [IndexService.UpdateIndex][google.cloud.aiplatform.v1beta1.IndexService.UpdateIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateIndexRequest = src.UpdateIndexRequest

// Runtime operation information for
// [JobService.UpdateModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.UpdateModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateModelDeploymentMonitoringJobOperationMetadata = src.UpdateModelDeploymentMonitoringJobOperationMetadata

// Request message for
// [JobService.UpdateModelDeploymentMonitoringJob][google.cloud.aiplatform.v1beta1.JobService.UpdateModelDeploymentMonitoringJob].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateModelDeploymentMonitoringJobRequest = src.UpdateModelDeploymentMonitoringJobRequest

// Request message for
// [ModelService.UpdateModel][google.cloud.aiplatform.v1beta1.ModelService.UpdateModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateModelRequest = src.UpdateModelRequest

// Runtime operation metadata for
// [SpecialistPoolService.UpdateSpecialistPool][google.cloud.aiplatform.v1beta1.SpecialistPoolService.UpdateSpecialistPool].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateSpecialistPoolOperationMetadata = src.UpdateSpecialistPoolOperationMetadata

// Request message for
// [SpecialistPoolService.UpdateSpecialistPool][google.cloud.aiplatform.v1beta1.SpecialistPoolService.UpdateSpecialistPool].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateSpecialistPoolRequest = src.UpdateSpecialistPoolRequest

// Request message for
// [TensorboardService.UpdateTensorboardExperiment][google.cloud.aiplatform.v1beta1.TensorboardService.UpdateTensorboardExperiment].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateTensorboardExperimentRequest = src.UpdateTensorboardExperimentRequest

// Details of operations that perform update Tensorboard.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateTensorboardOperationMetadata = src.UpdateTensorboardOperationMetadata

// Request message for
// [TensorboardService.UpdateTensorboard][google.cloud.aiplatform.v1beta1.TensorboardService.UpdateTensorboard].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateTensorboardRequest = src.UpdateTensorboardRequest

// Request message for
// [TensorboardService.UpdateTensorboardRun][google.cloud.aiplatform.v1beta1.TensorboardService.UpdateTensorboardRun].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateTensorboardRunRequest = src.UpdateTensorboardRunRequest

// Request message for
// [TensorboardService.UpdateTensorboardTimeSeries][google.cloud.aiplatform.v1beta1.TensorboardService.UpdateTensorboardTimeSeries].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpdateTensorboardTimeSeriesRequest = src.UpdateTensorboardTimeSeriesRequest

// Details of
// [ModelService.UploadModel][google.cloud.aiplatform.v1beta1.ModelService.UploadModel]
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UploadModelOperationMetadata = src.UploadModelOperationMetadata

// Request message for
// [ModelService.UploadModel][google.cloud.aiplatform.v1beta1.ModelService.UploadModel].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UploadModelRequest = src.UploadModelRequest

// Response message of
// [ModelService.UploadModel][google.cloud.aiplatform.v1beta1.ModelService.UploadModel]
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UploadModelResponse = src.UploadModelResponse

// Request message for
// [IndexService.UpsertDatapoints][google.cloud.aiplatform.v1beta1.IndexService.UpsertDatapoints]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpsertDatapointsRequest = src.UpsertDatapointsRequest

// Response message for
// [IndexService.UpsertDatapoints][google.cloud.aiplatform.v1beta1.IndexService.UpsertDatapoints]
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UpsertDatapointsResponse = src.UpsertDatapointsResponse

// References an API call. It contains more information about long running
// operation and Jobs that are triggered by the API call.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type UserActionReference = src.UserActionReference
type UserActionReference_DataLabelingJob = src.UserActionReference_DataLabelingJob
type UserActionReference_Operation = src.UserActionReference_Operation

// Value is the value of the field.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type Value = src.Value
type Value_DoubleValue = src.Value_DoubleValue
type Value_IntValue = src.Value_IntValue
type Value_StringValue = src.Value_StringValue

// VizierServiceClient is the client API for VizierService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type VizierServiceClient = src.VizierServiceClient

// VizierServiceServer is the server API for VizierService service.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type VizierServiceServer = src.VizierServiceServer

// Represents the spec of a worker pool in a job.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WorkerPoolSpec = src.WorkerPoolSpec
type WorkerPoolSpec_ContainerSpec = src.WorkerPoolSpec_ContainerSpec
type WorkerPoolSpec_PythonPackageSpec = src.WorkerPoolSpec_PythonPackageSpec

// Contains Feature values to be written for a specific entity.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteFeatureValuesPayload = src.WriteFeatureValuesPayload

// Request message for
// [FeaturestoreOnlineServingService.WriteFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreOnlineServingService.WriteFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteFeatureValuesRequest = src.WriteFeatureValuesRequest

// Response message for
// [FeaturestoreOnlineServingService.WriteFeatureValues][google.cloud.aiplatform.v1beta1.FeaturestoreOnlineServingService.WriteFeatureValues].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteFeatureValuesResponse = src.WriteFeatureValuesResponse

// Request message for
// [TensorboardService.WriteTensorboardExperimentData][google.cloud.aiplatform.v1beta1.TensorboardService.WriteTensorboardExperimentData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteTensorboardExperimentDataRequest = src.WriteTensorboardExperimentDataRequest

// Response message for
// [TensorboardService.WriteTensorboardExperimentData][google.cloud.aiplatform.v1beta1.TensorboardService.WriteTensorboardExperimentData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteTensorboardExperimentDataResponse = src.WriteTensorboardExperimentDataResponse

// Request message for
// [TensorboardService.WriteTensorboardRunData][google.cloud.aiplatform.v1beta1.TensorboardService.WriteTensorboardRunData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteTensorboardRunDataRequest = src.WriteTensorboardRunDataRequest

// Response message for
// [TensorboardService.WriteTensorboardRunData][google.cloud.aiplatform.v1beta1.TensorboardService.WriteTensorboardRunData].
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type WriteTensorboardRunDataResponse = src.WriteTensorboardRunDataResponse

// An explanation method that redistributes Integrated Gradients attributions
// to segmented regions, taking advantage of the model's fully differentiable
// structure. Refer to this paper for more details:
// https://arxiv.org/abs/1906.02825 Supported only by image Models.
//
// Deprecated: Please use types in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
type XraiAttribution = src.XraiAttribution

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewDatasetServiceClient(cc grpc.ClientConnInterface) DatasetServiceClient {
	return src.NewDatasetServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewDeploymentResourcePoolServiceClient(cc grpc.ClientConnInterface) DeploymentResourcePoolServiceClient {
	return src.NewDeploymentResourcePoolServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewEndpointServiceClient(cc grpc.ClientConnInterface) EndpointServiceClient {
	return src.NewEndpointServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewFeaturestoreOnlineServingServiceClient(cc grpc.ClientConnInterface) FeaturestoreOnlineServingServiceClient {
	return src.NewFeaturestoreOnlineServingServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewFeaturestoreServiceClient(cc grpc.ClientConnInterface) FeaturestoreServiceClient {
	return src.NewFeaturestoreServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewIndexEndpointServiceClient(cc grpc.ClientConnInterface) IndexEndpointServiceClient {
	return src.NewIndexEndpointServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewIndexServiceClient(cc grpc.ClientConnInterface) IndexServiceClient {
	return src.NewIndexServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewJobServiceClient(cc grpc.ClientConnInterface) JobServiceClient {
	return src.NewJobServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewMetadataServiceClient(cc grpc.ClientConnInterface) MetadataServiceClient {
	return src.NewMetadataServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewMigrationServiceClient(cc grpc.ClientConnInterface) MigrationServiceClient {
	return src.NewMigrationServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewModelServiceClient(cc grpc.ClientConnInterface) ModelServiceClient {
	return src.NewModelServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewPipelineServiceClient(cc grpc.ClientConnInterface) PipelineServiceClient {
	return src.NewPipelineServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewPredictionServiceClient(cc grpc.ClientConnInterface) PredictionServiceClient {
	return src.NewPredictionServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewSpecialistPoolServiceClient(cc grpc.ClientConnInterface) SpecialistPoolServiceClient {
	return src.NewSpecialistPoolServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewTensorboardServiceClient(cc grpc.ClientConnInterface) TensorboardServiceClient {
	return src.NewTensorboardServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func NewVizierServiceClient(cc grpc.ClientConnInterface) VizierServiceClient {
	return src.NewVizierServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterDatasetServiceServer(s *grpc.Server, srv DatasetServiceServer) {
	src.RegisterDatasetServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterDeploymentResourcePoolServiceServer(s *grpc.Server, srv DeploymentResourcePoolServiceServer) {
	src.RegisterDeploymentResourcePoolServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterEndpointServiceServer(s *grpc.Server, srv EndpointServiceServer) {
	src.RegisterEndpointServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterFeaturestoreOnlineServingServiceServer(s *grpc.Server, srv FeaturestoreOnlineServingServiceServer) {
	src.RegisterFeaturestoreOnlineServingServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterFeaturestoreServiceServer(s *grpc.Server, srv FeaturestoreServiceServer) {
	src.RegisterFeaturestoreServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterIndexEndpointServiceServer(s *grpc.Server, srv IndexEndpointServiceServer) {
	src.RegisterIndexEndpointServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterIndexServiceServer(s *grpc.Server, srv IndexServiceServer) {
	src.RegisterIndexServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterJobServiceServer(s *grpc.Server, srv JobServiceServer) {
	src.RegisterJobServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterMetadataServiceServer(s *grpc.Server, srv MetadataServiceServer) {
	src.RegisterMetadataServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterMigrationServiceServer(s *grpc.Server, srv MigrationServiceServer) {
	src.RegisterMigrationServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterModelServiceServer(s *grpc.Server, srv ModelServiceServer) {
	src.RegisterModelServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterPipelineServiceServer(s *grpc.Server, srv PipelineServiceServer) {
	src.RegisterPipelineServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterPredictionServiceServer(s *grpc.Server, srv PredictionServiceServer) {
	src.RegisterPredictionServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterSpecialistPoolServiceServer(s *grpc.Server, srv SpecialistPoolServiceServer) {
	src.RegisterSpecialistPoolServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterTensorboardServiceServer(s *grpc.Server, srv TensorboardServiceServer) {
	src.RegisterTensorboardServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/aiplatform/apiv1beta1/aiplatformpb
func RegisterVizierServiceServer(s *grpc.Server, srv VizierServiceServer) {
	src.RegisterVizierServiceServer(s, srv)
}
